@@ -1,7 +1,7 @@
 /*
-    $Id: vcd_xml_build.c,v 1.24 2004/10/10 20:20:19 rocky Exp $
+    $Id: vcd_xml_build.c,v 1.26 2005/05/07 19:53:21 rocky Exp $
 
-    Copyright (C) 2001,2003 Herbert Valerio Riedel <hvr@gnu.org>
+    Copyright (C) 2001, 2003, 2005 Herbert Valerio Riedel <hvr@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@
 #include "vcd_xml_dtd.h"
 #include "vcd_xml_common.h"
 
-static const char _rcsid[] = "$Id: vcd_xml_build.c,v 1.24 2004/10/10 20:20:19 rocky Exp $";
+static const char _rcsid[] = "$Id: vcd_xml_build.c,v 1.26 2005/05/07 19:53:21 rocky Exp $";
 
 static void
 _init_xml (void)
@@ -132,7 +132,7 @@ static struct {
     IMG_TYPE_NRG
   } img_type;
 
-  CdioList *img_options;
+  CdioList_t *img_options;
 
   char *xml_fname;
   char *file_prefix;
@@ -158,7 +158,7 @@ _set_img_opt (const char key[], const char val[])
   if (!key || !val)
     vcd_error ("invalid image option");
 
-  _cons = _vcd_malloc (sizeof (struct key_val_t));
+  _cons = calloc(1, sizeof (struct key_val_t));
   _cons->key = strdup (key);
   _cons->val = strdup (val);
 
@@ -357,7 +357,7 @@ static VcdImageSink *
 _create_sink (void)
 {
   VcdImageSink *image_sink = NULL;
-  CdioListNode *node;
+  CdioListNode_t *node;
 
   switch (gl.img_type)
     {
@@ -395,6 +395,8 @@ main (int argc, const char *argv[])
   time_t create_time;
   xmlDocPtr vcd_doc;
 
+  memset(&gl, 0, sizeof(gl));
+  
   vcd_xml_progname = "vcdxbuild";
 
   _init_xml ();
@@ -405,7 +407,7 @@ main (int argc, const char *argv[])
   gl.create_timestr = NULL;
 
   if (_do_cl (argc, argv))
-    return EXIT_FAILURE;
+    goto err_exit;
 
   if (gl.quiet_flag)
     vcd_xml_verbosity = VCD_LOG_WARN;
@@ -427,26 +429,26 @@ main (int argc, const char *argv[])
   if (!(vcd_doc = _xmlParseFile (gl.xml_fname)))
     {
       if (errno)
-	vcd_error ("error while parsing file `%s': %s",
+	vcd_warn ("error while parsing file `%s': %s",
 		   gl.xml_fname, strerror (errno));
       else
-	vcd_error ("parsing file `%s' failed", gl.xml_fname);
-      return EXIT_FAILURE;
+	vcd_warn ("parsing file `%s' failed", gl.xml_fname);
+      goto err_exit;
     }
 
   if (vcd_xml_dtd_loaded < 1)
     {
       vcd_error ("doctype declaration missing in `%s'", gl.xml_fname);
-      return EXIT_FAILURE;
+      goto err_exit;
     }
 
   {
     xmlNodePtr root;
     xmlNsPtr ns;
-    struct vcdxml_t obj;
+    vcdxml_t vcdxml;
     VcdImageSink *image_sink;
 
-    vcd_xml_init (&obj);
+    vcd_xml_init (&vcdxml);
     
     if (!(root = xmlDocGetRootElement (vcd_doc)))
       vcd_error ("XML document seems to be empty (no root node found)");
@@ -454,16 +456,16 @@ main (int argc, const char *argv[])
     if (!(ns = xmlSearchNsByHref (vcd_doc, root, (const xmlChar *) VIDEOCD_DTD_XMLNS)))
       vcd_error ("Namespace not found in document");
     
-    if (vcd_xml_parse (&obj, vcd_doc, root, ns))
+    if (vcd_xml_parse (&vcdxml, vcd_doc, root, ns))
       vcd_error ("parsing tree failed");
 
     if (!(image_sink = _create_sink (/* gl */)))
       {
         vcd_error ("failed to create image object");
-        exit (EXIT_FAILURE);
+        goto err_exit;
       }
 
-    obj.file_prefix = gl.file_prefix;
+    vcdxml.file_prefix = gl.file_prefix;
     
     create_time = time(NULL);
     if (gl.create_timestr != NULL) {
@@ -486,11 +488,21 @@ main (int argc, const char *argv[])
       }
     }
   
-    if (vcd_xml_master (&obj, image_sink, &create_time))
-      vcd_error ("building videocd failed");
+    if (vcd_xml_master (&vcdxml, image_sink, &create_time)) {
+      vcd_warn ("building videocd failed");
+      goto err_exit;
+    }
+    
+    
+    vcd_xml_destroy(&vcdxml);
   } 
 
   xmlFreeDoc (vcd_doc);
-
+  free(gl.xml_fname);
+  _cdio_list_free (gl.img_options, true);
   return EXIT_SUCCESS;
+ err_exit: 
+  free(gl.xml_fname);
+  _cdio_list_free (gl.img_options, true);
+  return EXIT_FAILURE;
 }
