@@ -1,5 +1,5 @@
 /*
-    $Id: vcd_xml_master.h,v 1.6 2003/11/10 11:57:48 rocky Exp $
+    $Id: vcd_xml_master.h,v 1.7 2005/05/07 19:53:21 rocky Exp $
 
     Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -24,7 +24,7 @@
 
 #include <time.h>
 
-bool vcd_xml_master (const struct vcdxml_t *obj, 
+bool vcd_xml_master (const vcdxml_t *p_vcdxml, 
 		     VcdImageSink *image_sink, time_t *create_time);
 
 #endif /* __VCD_XML_MASTER_H__ */
