@@ -1,7 +1,8 @@
 /*
-    $Id: vcd_xml_rip.c,v 1.63 2004/12/01 13:04:59 rocky Exp $
+    $Id: vcd_xml_rip.c,v 1.70 2005/05/07 19:53:21 rocky Exp $
 
-    Copyright (C) 2001, 2003, 2004 Herbert Valerio Riedel <hvr@gnu.org>
+    Copyright (C) 2001, 2003, 2004, 2005 Herbert Valerio Riedel <hvr@gnu.org>
+    Copyright (C) 2005 Rocky Bernstein <rocky@panix.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -62,13 +63,13 @@
 
 #include <popt.h>
 
-static const char _rcsid[] = "$Id: vcd_xml_rip.c,v 1.63 2004/12/01 13:04:59 rocky Exp $";
+static const char _rcsid[] = "$Id: vcd_xml_rip.c,v 1.70 2005/05/07 19:53:21 rocky Exp $";
 
 static int _verbose_flag = 0;
 static int _quiet_flag = 0;
 
 static void
-_register_file (struct vcdxml_t *obj, const char *pathname,
+_register_file (vcdxml_t *p_vcdxml, const char *pathname,
 		iso9660_stat_t const *statbuf)
 {
   uint16_t xa_attr = uint16_from_be (statbuf->xa.attributes);
@@ -80,24 +81,24 @@ _register_file (struct vcdxml_t *obj, const char *pathname,
     {
     case _STAT_DIR:
 	{
-	  struct filesystem_t *_fs 
-	    = _vcd_malloc (sizeof (struct filesystem_t));
-	  _cdio_list_append (obj->filesystem, _fs);
+	  struct filesystem_t *p_fs 
+	    = calloc(1, sizeof (struct filesystem_t));
+	  _cdio_list_append (p_vcdxml->filesystem, p_fs);
 	  
-	  _fs->name = strdup (pathname);
+	  p_fs->name = strdup (pathname);
 	}
       break;
 
     case _STAT_FILE:
       {
 	char *namebuf = strdup (pathname);
-	struct filesystem_t *_fs = _vcd_malloc (sizeof (struct filesystem_t));
-	_cdio_list_append (obj->filesystem, _fs);
+	struct filesystem_t *p_fs = calloc(1, sizeof (struct filesystem_t));
+	_cdio_list_append (p_vcdxml->filesystem, p_fs);
 
 	if (strrchr (namebuf, ';'))
 	  *strrchr (namebuf, ';') = '\0';
 
-	_fs->name = namebuf;
+	p_fs->name = namebuf;
 
 	{
 	  char namebuf2[strlen (namebuf) + 2];
@@ -110,23 +111,23 @@ _register_file (struct vcdxml_t *obj, const char *pathname,
 
 	  namebuf2[i + 1] = '\0';
 
-	  _fs->file_src = strdup (namebuf2);
+	  p_fs->file_src = strdup (namebuf2);
 	}
 
-	_fs->lsn = statbuf->lsn;
-	_fs->size = statbuf->size;
-	_fs->file_raw = (xa_attr & XA_ATTR_MODE2FORM2) != 0;
+	p_fs->lsn = statbuf->lsn;
+	p_fs->size = statbuf->size;
+	p_fs->file_raw = (xa_attr & XA_ATTR_MODE2FORM2) != 0;
 
 	vcd_debug ("file %s", namebuf);
 
-	if (_fs->file_raw)
+	if (p_fs->file_raw)
 	  {
-	    if (_fs->size % ISO_BLOCKSIZE == 0)
+	    if (p_fs->size % ISO_BLOCKSIZE == 0)
 	      { 
-		_fs->size /= ISO_BLOCKSIZE;
-		_fs->size *= M2RAW_SECTOR_SIZE;
+		p_fs->size /= ISO_BLOCKSIZE;
+		p_fs->size *= M2RAW_SECTOR_SIZE;
 	      }
-	    else if (_fs->size % M2RAW_SECTOR_SIZE == 0)
+	    else if (p_fs->size % M2RAW_SECTOR_SIZE == 0)
 	      vcd_warn ("detected wrong size calculation for form2 file `%s'; fixing up", namebuf);
 	    else 
 	      vcd_error ("form2 file has invalid file size");
@@ -141,10 +142,11 @@ _register_file (struct vcdxml_t *obj, const char *pathname,
 }
 
 static int
-_parse_isofs_r (struct vcdxml_t *obj, CdIo *img, const char pathname[])
+_parse_isofs_r (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, 
+		const char pathname[])
 { 
-  CdioList *entlist = iso9660_fs_readdir (img, pathname, true);
-  CdioListNode *entnode;
+  CdioList_t *entlist = iso9660_fs_readdir (p_cdio, pathname, true);
+  CdioListNode_t *entnode;
 
   if (entlist == NULL)
     return -1;
@@ -172,11 +174,11 @@ _parse_isofs_r (struct vcdxml_t *obj, CdIo *img, const char pathname[])
 	  || !strcmp (_name, "CDDA"))
 	continue;
 
-      _register_file (obj, _fullname, statbuf);
+      _register_file (p_vcdxml, _fullname, statbuf);
 
       if (statbuf->type == _STAT_DIR) {
 	strncat (_fullname, "/", sizeof (_fullname));
-	if (_parse_isofs_r (obj, img, _fullname)) {
+	if (_parse_isofs_r (p_vcdxml, p_cdio, _fullname)) {
 	  return -1;
 	}
       }
@@ -188,56 +190,56 @@ _parse_isofs_r (struct vcdxml_t *obj, CdIo *img, const char pathname[])
 }
 
 static int
-_parse_isofs (struct vcdxml_t *obj, CdIo *img)
+_parse_isofs (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 {
-  return _parse_isofs_r (obj, img, "/");
+  return _parse_isofs_r (p_vcdxml, p_cdio, "/");
 }
 
 static int
-_parse_pvd (struct vcdxml_t *obj, CdIo *img)
+_parse_pvd (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 {
   iso9660_pvd_t pvd;
 
   memset (&pvd, 0, sizeof (iso9660_pvd_t));
   vcd_assert (sizeof (iso9660_pvd_t) == ISO_BLOCKSIZE);
 
-  if (!iso9660_fs_read_pvd(img, &pvd)) {
+  if (!iso9660_fs_read_pvd(p_cdio, &pvd)) {
     return -1;
   }
 
-  obj->pvd.volume_id      = strdup (iso9660_get_volume_id(&pvd));
-  obj->pvd.system_id      = strdup (iso9660_get_system_id(&pvd));
-  obj->pvd.publisher_id   = strdup (iso9660_get_publisher_id(&pvd));
-  obj->pvd.preparer_id    = strdup (iso9660_get_preparer_id(&pvd));
-  obj->pvd.application_id = strdup (iso9660_get_application_id(&pvd));
+  p_vcdxml->pvd.volume_id      = iso9660_get_volume_id(&pvd);
+  p_vcdxml->pvd.system_id      = iso9660_get_system_id(&pvd);
+  p_vcdxml->pvd.publisher_id   = iso9660_get_publisher_id(&pvd);
+  p_vcdxml->pvd.preparer_id    = iso9660_get_preparer_id(&pvd);
+  p_vcdxml->pvd.application_id = iso9660_get_application_id(&pvd);
 
   return 0;
 }
 
 static int
-_parse_info (struct vcdxml_t *obj, CdIo *img)
+_parse_info (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 {
   InfoVcd_t info;
 
   memset (&info, 0, sizeof (InfoVcd_t));
   vcd_assert (sizeof (InfoVcd_t) == ISO_BLOCKSIZE);
 
-  if (!read_info(img, &info, &(obj->vcd_type)))
+  if (!read_info(p_cdio, &info, &(p_vcdxml->vcd_type)))
     return -1;
 
-  if (obj->vcd_type == VCD_TYPE_INVALID)
+  if (p_vcdxml->vcd_type == VCD_TYPE_INVALID)
     return -1;
 
-  obj->info.album_id = strdup (vcdinf_get_album_id(&info));
-  obj->info.volume_count = vcdinf_get_volume_count(&info);
-  obj->info.volume_number = vcdinf_get_volume_num(&info);
+  p_vcdxml->info.album_id      = strdup (vcdinf_get_album_id(&info));
+  p_vcdxml->info.volume_count  = vcdinf_get_volume_count(&info);
+  p_vcdxml->info.volume_number = vcdinf_get_volume_num(&info);
 
-  obj->info.restriction = info.flags.restriction;
-  obj->info.use_lid2 = info.flags.use_lid2;
-  obj->info.use_sequence2 = info.flags.use_track3;
+  p_vcdxml->info.restriction = info.flags.restriction;
+  p_vcdxml->info.use_lid2 = info.flags.use_lid2;
+  p_vcdxml->info.use_sequence2 = info.flags.use_track3;
 
-  obj->info.psd_size = vcdinf_get_psd_size(&info);
-  obj->info.max_lid = vcdinf_get_num_LIDs(&info);
+  p_vcdxml->info.psd_size = vcdinf_get_psd_size(&info);
+  p_vcdxml->info.max_lid = vcdinf_get_num_LIDs(&info);
 
   {
     lba_t segment_start;
@@ -256,7 +258,7 @@ _parse_info (struct vcdxml_t *obj, CdIo *img)
 
     vcd_assert (segment_start % CDIO_CD_FRAMES_PER_SEC == 0);
 
-    obj->info.segments_start = segment_start;
+    p_vcdxml->info.segments_start = segment_start;
 
     if (!max_seg_num)
       return 0;
@@ -267,7 +269,7 @@ _parse_info (struct vcdxml_t *obj, CdIo *img)
 	if (!info.spi_contents[idx].item_cont)
 	  { /* new segment */
 	    char buf[80];
-	    _segment = _vcd_malloc (sizeof (struct segment_t));
+	    _segment = calloc(1, sizeof (struct segment_t));
 
 	    snprintf (buf, sizeof (buf), "segment-%4.4d", idx);
 	    _segment->id = strdup (buf);
@@ -277,7 +279,7 @@ _parse_info (struct vcdxml_t *obj, CdIo *img)
 
 	    _segment->autopause_list = _cdio_list_new ();
 
-	    _cdio_list_append (obj->segment_list, _segment);
+	    _cdio_list_append (p_vcdxml->segment_list, _segment);
 	    n++;
 	  }
 
@@ -291,7 +293,7 @@ _parse_info (struct vcdxml_t *obj, CdIo *img)
 }
 
 static int
-_parse_entries (struct vcdxml_t *obj, CdIo *img)
+_parse_entries (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 {
   EntriesVcd_t entries;
   int idx;
@@ -300,7 +302,7 @@ _parse_entries (struct vcdxml_t *obj, CdIo *img)
   memset (&entries, 0, sizeof (EntriesVcd_t));
   vcd_assert (sizeof (EntriesVcd_t) == ISO_BLOCKSIZE);
 
-  if (!read_entries(img, &entries)) {
+  if (!read_entries(p_cdio, &entries)) {
     return -1;
   }
 
@@ -321,39 +323,40 @@ _parse_entries (struct vcdxml_t *obj, CdIo *img)
       if (newtrack)
 	{
 	  char buf[80];
-	  struct sequence_t *_new_sequence;
+	  struct sequence_t *p_new_sequence;
 
-	  _new_sequence = _vcd_malloc (sizeof (struct sequence_t));
+	  p_new_sequence = calloc(1, sizeof (struct sequence_t));
 
 	  snprintf (buf, sizeof (buf), "sequence-%2.2d", track);
-	  _new_sequence->id = strdup (buf);
+	  p_new_sequence->id = strdup (buf);
 
 	  snprintf (buf, sizeof (buf), "avseq%2.2d.mpg", track + 1);
-	  _new_sequence->src = strdup (buf);
+	  p_new_sequence->src = strdup (buf);
 
-	  _new_sequence->entry_point_list = _cdio_list_new ();
-	  _new_sequence->autopause_list = _cdio_list_new ();
-	  _new_sequence->start_extent = extent;
+	  p_new_sequence->entry_point_list = _cdio_list_new ();
+	  p_new_sequence->autopause_list = _cdio_list_new ();
+	  p_new_sequence->start_extent = extent;
 
 	  snprintf (buf, sizeof (buf), "entry-%3.3d", idx);
-	  _new_sequence->default_entry_id = strdup (buf);
+	  p_new_sequence->default_entry_id = strdup (buf);
 	  
-	  _cdio_list_append (obj->sequence_list, _new_sequence);
+	  _cdio_list_append (p_vcdxml->sequence_list, p_new_sequence);
 	}
       else
 	{
 	  char buf[80];
-	  struct sequence_t *_seq =
-	    _cdio_list_node_data (_cdio_list_end (obj->sequence_list));
+	  struct sequence_t *p_seq =
+	    _cdio_list_node_data (_cdio_list_end (p_vcdxml->sequence_list));
 
-	  struct entry_point_t *_entry = _vcd_malloc (sizeof (struct entry_point_t));
+	  struct entry_point_t *p_entry = 
+	    calloc(1, sizeof (struct entry_point_t));
 
 	  snprintf (buf, sizeof (buf), "entry-%3.3d", idx);
-	  _entry->id = strdup (buf);
+	  p_entry->id = strdup (buf);
 
-	  _entry->extent = extent;
+	  p_entry->extent = extent;
 
-	  _cdio_list_append (_seq->entry_point_list, _entry);
+	  _cdio_list_append (p_seq->entry_point_list, p_entry);
 	}
 
       /* vcd_debug ("%d %d %d %d", idx, track, extent, newtrack); */
@@ -371,16 +374,16 @@ _xstrdup(const char *s)
   return NULL;
 }
 
-struct _pbc_ctx {
+typedef struct _pbc_ctx {
   unsigned psd_size;
   unsigned maximum_lid;
   unsigned offset_mult;
-  CdioList *offset_list;
+  CdioList_t *offset_list;
 
   uint8_t *psd;
   LotVcd_t *lot;
   bool extended;
-};
+} pbc_ctx_t ;
 
 static const char *
 _pin2id (unsigned pin)
@@ -410,9 +413,9 @@ _pin2id (unsigned pin)
 }
 
 static const char *
-_ofs2id (unsigned offset, const struct _pbc_ctx *_ctx)
+_ofs2id (unsigned offset, const pbc_ctx_t *_ctx)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   static char buf[80];
   unsigned sl_num = 0, el_num = 0, pl_num = 0;
   vcdinfo_offset_t *ofs = NULL;
@@ -477,14 +480,14 @@ _ofs2id (unsigned offset, const struct _pbc_ctx *_ctx)
 }
 
 static pbc_t *
-_pbc_node_read (const struct _pbc_ctx *_ctx, unsigned offset)
+_pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
 {
-  pbc_t *_pbc = NULL;
+  pbc_t *p_pbc = NULL;
   const uint8_t *_buf = &_ctx->psd[offset * _ctx->offset_mult];
   vcdinfo_offset_t *ofs = NULL;
 
   {
-    CdioListNode *node;
+    CdioListNode_t *node;
     _CDIO_LIST_FOREACH (node, _ctx->offset_list)
       {
 	ofs = _cdio_list_node_data (node);
@@ -500,22 +503,22 @@ _pbc_node_read (const struct _pbc_ctx *_ctx, unsigned offset)
       int n;
 
     case PSD_TYPE_PLAY_LIST:
-      _pbc = vcd_pbc_new (PBC_PLAYLIST);
+      p_pbc = vcd_pbc_new (PBC_PLAYLIST);
       {
 	const PsdPlayListDescriptor_t *d = (const void *) _buf;
-	_pbc->prev_id = _xstrdup (_ofs2id (vcdinf_pld_get_prev_offset(d), 
+	p_pbc->prev_id = _xstrdup (_ofs2id (vcdinf_pld_get_prev_offset(d), 
 					   _ctx));
-	_pbc->next_id = _xstrdup (_ofs2id (vcdinf_pld_get_next_offset(d),
+	p_pbc->next_id = _xstrdup (_ofs2id (vcdinf_pld_get_next_offset(d),
 					   _ctx));
-	_pbc->retn_id = _xstrdup (_ofs2id (vcdinf_pld_get_return_offset(d),
+	p_pbc->retn_id = _xstrdup (_ofs2id (vcdinf_pld_get_return_offset(d),
 					   _ctx));
 	
-	_pbc->playing_time = (double) (vcdinf_get_play_time(d)) / 15.0;
-	_pbc->wait_time       = vcdinf_get_wait_time(d);
-	_pbc->auto_pause_time = vcdinf_get_autowait_time(d);
+	p_pbc->playing_time = (double) (vcdinf_get_play_time(d)) / 15.0;
+	p_pbc->wait_time       = vcdinf_get_wait_time(d);
+	p_pbc->auto_pause_time = vcdinf_get_autowait_time(d);
 
 	for (n = 0; n < vcdinf_pld_get_noi(d); n++) {
-	  _cdio_list_append (_pbc->item_id_list, 
+	  _cdio_list_append (p_pbc->item_id_list, 
 			    _xstrdup(_pin2id(vcdinf_pld_get_play_item(d,n)
 					     )));
 	  }
@@ -524,51 +527,51 @@ _pbc_node_read (const struct _pbc_ctx *_ctx, unsigned offset)
 
     case PSD_TYPE_EXT_SELECTION_LIST:
     case PSD_TYPE_SELECTION_LIST:
-      _pbc = vcd_pbc_new (PBC_SELECTION);
+      p_pbc = vcd_pbc_new (PBC_SELECTION);
       {
 	const PsdSelectionListDescriptor_t *d = (const void *) _buf;
-	_pbc->bsn = vcdinf_get_bsn(d);
-	_pbc->prev_id = _xstrdup (_ofs2id (vcdinf_psd_get_prev_offset(d), 
+	p_pbc->bsn = vcdinf_get_bsn(d);
+	p_pbc->prev_id = _xstrdup (_ofs2id (vcdinf_psd_get_prev_offset(d), 
 					   _ctx));
-	_pbc->next_id = _xstrdup (_ofs2id (vcdinf_psd_get_next_offset(d), 
+	p_pbc->next_id = _xstrdup (_ofs2id (vcdinf_psd_get_next_offset(d), 
 					   _ctx));
-	_pbc->retn_id = _xstrdup (_ofs2id (vcdinf_psd_get_return_offset(d),
+	p_pbc->retn_id = _xstrdup (_ofs2id (vcdinf_psd_get_return_offset(d),
 					   _ctx));
 
 	switch (vcdinf_psd_get_default_offset(d))
 	  {
 	  case PSD_OFS_DISABLED:
-	    _pbc->default_id = NULL;
-	    _pbc->selection_type = _SEL_NORMAL;
+	    p_pbc->default_id = NULL;
+	    p_pbc->selection_type = _SEL_NORMAL;
 	    break;
 
 	  case PSD_OFS_MULTI_DEF:
-	    _pbc->default_id = NULL;
-	    _pbc->selection_type = _SEL_MULTI_DEF;
+	    p_pbc->default_id = NULL;
+	    p_pbc->selection_type = _SEL_MULTI_DEF;
 	    break;
 
 	  case PSD_OFS_MULTI_DEF_NO_NUM:
-	    _pbc->default_id = NULL;
-	    _pbc->selection_type = _SEL_MULTI_DEF_NO_NUM;
+	    p_pbc->default_id = NULL;
+	    p_pbc->selection_type = _SEL_MULTI_DEF_NO_NUM;
 	    break;
 
 	  default:
-	    _pbc->default_id = _xstrdup (_ofs2id (vcdinf_psd_get_default_offset(d),
+	    p_pbc->default_id = _xstrdup (_ofs2id (vcdinf_psd_get_default_offset(d),
 						  _ctx));
-	    _pbc->selection_type = _SEL_NORMAL;
+	    p_pbc->selection_type = _SEL_NORMAL;
 	    break;
 	  }
 
-	_pbc->timeout_id   = _xstrdup (_ofs2id (vcdinf_get_timeout_offset(d), 
+	p_pbc->timeout_id   = _xstrdup (_ofs2id (vcdinf_get_timeout_offset(d), 
 						_ctx));
-	_pbc->timeout_time = vcdinf_get_timeout_time (d);
-	_pbc->jump_delayed = vcdinf_has_jump_delay(d);
-	_pbc->loop_count   = vcdinf_get_loop_count(d);
-	_pbc->item_id      = _xstrdup (_pin2id (vcdinf_psd_get_itemid(d)));
+	p_pbc->timeout_time = vcdinf_get_timeout_time (d);
+	p_pbc->jump_delayed = vcdinf_has_jump_delay(d);
+	p_pbc->loop_count   = vcdinf_get_loop_count(d);
+	p_pbc->item_id      = _xstrdup (_pin2id (vcdinf_psd_get_itemid(d)));
 
 	for (n = 0; n < vcdinf_get_num_selections(d); n++)
 	  {
-	    _cdio_list_append (_pbc->select_id_list, 
+	    _cdio_list_append (p_pbc->select_id_list, 
 			      _xstrdup(_ofs2id(vcdinf_psd_get_offset(d,n),
 					       _ctx)));
 	  }
@@ -576,40 +579,41 @@ _pbc_node_read (const struct _pbc_ctx *_ctx, unsigned offset)
 	if (d->type == PSD_TYPE_EXT_SELECTION_LIST
 	    || d->flags.SelectionAreaFlag)
 	  {
-	    PsdSelectionListDescriptorExtended *d2 = (void *) &d->ofs[d->nos];
+	    PsdSelectionListDescriptorExtended_t *d2 = 
+	      (void *) &d->ofs[d->nos];
 
-	    _pbc->prev_area = _vcd_malloc (sizeof (pbc_area_t));
-	    _pbc->next_area = _vcd_malloc (sizeof (pbc_area_t));
-	    _pbc->return_area = _vcd_malloc (sizeof (pbc_area_t));
-	    _pbc->default_area = _vcd_malloc (sizeof (pbc_area_t));
+	    p_pbc->prev_area = calloc(1, sizeof (pbc_area_t));
+	    p_pbc->next_area = calloc(1, sizeof (pbc_area_t));
+	    p_pbc->return_area = calloc(1, sizeof (pbc_area_t));
+	    p_pbc->default_area = calloc(1, sizeof (pbc_area_t));
 
-	    *_pbc->prev_area = d2->prev_area;
-	    *_pbc->next_area = d2->next_area;
-	    *_pbc->return_area = d2->return_area;
-	    *_pbc->default_area = d2->default_area;
+	    *p_pbc->prev_area = d2->prev_area;
+	    *p_pbc->next_area = d2->next_area;
+	    *p_pbc->return_area = d2->return_area;
+	    *p_pbc->default_area = d2->default_area;
 
 	    for (n = 0; n < vcdinf_get_num_selections(d); n++)
 	      {
-		pbc_area_t *_area = _vcd_malloc (sizeof (pbc_area_t));
+		pbc_area_t *p_area = calloc(1, sizeof (pbc_area_t));
 
-		*_area = d2->area[n];
+		*p_area = d2->area[n];
 
-		_cdio_list_append (_pbc->select_area_list, _area);
+		_cdio_list_append (p_pbc->select_area_list, p_area);
 	      }
 
-	    vcd_assert (_cdio_list_length (_pbc->select_area_list) 
-			== _cdio_list_length (_pbc->select_id_list));
+	    vcd_assert (_cdio_list_length (p_pbc->select_area_list) 
+			== _cdio_list_length (p_pbc->select_id_list));
 	  }
       }
       break;
 
     case PSD_TYPE_END_LIST:
-      _pbc = vcd_pbc_new (PBC_END);
+      p_pbc = vcd_pbc_new (PBC_END);
       {
-	const PsdEndListDescriptor *d = (const void *) _buf;
+	const PsdEndListDescriptor_t *d = (const void *) _buf;
 	
-	_pbc->next_disc = d->next_disc;
-	_pbc->image_id = _xstrdup (_pin2id (uint16_from_be (d->change_pic)));
+	p_pbc->next_disc = d->next_disc;
+	p_pbc->image_id = _xstrdup (_pin2id (uint16_from_be (d->change_pic)));
       }      
       break;
 
@@ -618,23 +622,24 @@ _pbc_node_read (const struct _pbc_ctx *_ctx, unsigned offset)
       break;
     }
 
-  if (_pbc)
+  if (p_pbc)
     {
-      _pbc->id = _xstrdup (_ofs2id (offset, _ctx));
-      _pbc->rejected = !ofs->in_lot;
+      p_pbc->id = _xstrdup (_ofs2id (offset, _ctx));
+      p_pbc->rejected = !ofs->in_lot;
     }
 
-  return _pbc;
+  return p_pbc;
 }
 
 static void
-_visit_pbc (struct _pbc_ctx *obj, lid_t lid, unsigned int offset, bool in_lot)
+_visit_pbc (pbc_ctx_t *p_pbc_ctx, lid_t lid, unsigned int offset, 
+	    bool in_lot)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   vcdinfo_offset_t *ofs;
-  unsigned _rofs = offset * obj->offset_mult;
+  unsigned _rofs = offset * p_pbc_ctx->offset_mult;
 
-  vcd_assert (obj->psd_size % 8 == 0);
+  vcd_assert (p_pbc_ctx->psd_size % 8 == 0);
 
   switch (offset)
     {
@@ -647,9 +652,9 @@ _visit_pbc (struct _pbc_ctx *obj, lid_t lid, unsigned int offset, bool in_lot)
       break;
     }
 
-  if (_rofs >= obj->psd_size)
+  if (_rofs >= p_pbc_ctx->psd_size)
     {
-      if (obj->extended)
+      if (p_pbc_ctx->extended)
 	vcd_error ("psd offset out of range in extended PSD"
 		   " (try --no-ext-psd option)");
       else
@@ -657,12 +662,12 @@ _visit_pbc (struct _pbc_ctx *obj, lid_t lid, unsigned int offset, bool in_lot)
       return;
     }
 
-  vcd_assert (_rofs < obj->psd_size);
+  vcd_assert (_rofs < p_pbc_ctx->psd_size);
 
-  if (!obj->offset_list)
-    obj->offset_list = _cdio_list_new ();
+  if (!p_pbc_ctx->offset_list)
+    p_pbc_ctx->offset_list = _cdio_list_new ();
 
-  _CDIO_LIST_FOREACH (node, obj->offset_list)
+  _CDIO_LIST_FOREACH (node, p_pbc_ctx->offset_list)
     {
       ofs = _cdio_list_node_data (node);
 
@@ -683,19 +688,20 @@ _visit_pbc (struct _pbc_ctx *obj, lid_t lid, unsigned int offset, bool in_lot)
         }
     }
 
-  ofs = _vcd_malloc (sizeof (vcdinfo_offset_t));
+  ofs = calloc(1, sizeof (vcdinfo_offset_t));
 
   ofs->offset = offset;
   ofs->lid    = lid;
   ofs->in_lot = in_lot;
-  ofs->type   = obj->psd[_rofs];
+  ofs->type   = p_pbc_ctx->psd[_rofs];
 
   switch (ofs->type)
     {
     case PSD_TYPE_PLAY_LIST:
-      _cdio_list_append (obj->offset_list, ofs);
+      _cdio_list_append (p_pbc_ctx->offset_list, ofs);
       {
-        const PsdPlayListDescriptor_t *d = (const void *) (obj->psd + _rofs);
+        const PsdPlayListDescriptor_t *d = 
+	  (const void *) (p_pbc_ctx->psd + _rofs);
         const lid_t lid = vcdinf_pld_get_lid(d);
 
         if (!ofs->lid)
@@ -705,18 +711,18 @@ _visit_pbc (struct _pbc_ctx *obj, lid_t lid, unsigned int offset, bool in_lot)
             vcd_warn ("LOT entry assigned LID %d, but descriptor has LID %d",
                       ofs->lid, lid);
 
-        _visit_pbc (obj, 0, vcdinf_pld_get_prev_offset(d), false);
-        _visit_pbc (obj, 0, vcdinf_pld_get_next_offset(d), false);
-        _visit_pbc (obj, 0, vcdinf_pld_get_return_offset(d), false);
+        _visit_pbc (p_pbc_ctx, 0, vcdinf_pld_get_prev_offset(d), false);
+        _visit_pbc (p_pbc_ctx, 0, vcdinf_pld_get_next_offset(d), false);
+        _visit_pbc (p_pbc_ctx, 0, vcdinf_pld_get_return_offset(d), false);
       }
       break;
 
     case PSD_TYPE_EXT_SELECTION_LIST:
     case PSD_TYPE_SELECTION_LIST:
-      _cdio_list_append (obj->offset_list, ofs);
+      _cdio_list_append (p_pbc_ctx->offset_list, ofs);
       {
         const PsdSelectionListDescriptor_t *d =
-          (const void *) (obj->psd + _rofs);
+          (const void *) (p_pbc_ctx->psd + _rofs);
 
         int idx;
 	lid_t lid = vcdinf_psd_get_lid (d);
@@ -728,20 +734,20 @@ _visit_pbc (struct _pbc_ctx *obj, lid_t lid, unsigned int offset, bool in_lot)
             vcd_warn ("LOT entry assigned LID %d, but descriptor has LID %d",
                       ofs->lid, lid);
 
-        _visit_pbc (obj, 0, vcdinf_psd_get_prev_offset(d), false);
-        _visit_pbc (obj, 0, vcdinf_psd_get_next_offset(d), false);
-        _visit_pbc (obj, 0, vcdinf_psd_get_return_offset(d), false);
-        _visit_pbc (obj, 0, vcdinf_psd_get_default_offset(d), false);
-        _visit_pbc (obj, 0, vcdinf_get_timeout_offset(d), false);
+        _visit_pbc (p_pbc_ctx, 0, vcdinf_psd_get_prev_offset(d), false);
+        _visit_pbc (p_pbc_ctx, 0, vcdinf_psd_get_next_offset(d), false);
+        _visit_pbc (p_pbc_ctx, 0, vcdinf_psd_get_return_offset(d), false);
+        _visit_pbc (p_pbc_ctx, 0, vcdinf_psd_get_default_offset(d), false);
+        _visit_pbc (p_pbc_ctx, 0, vcdinf_get_timeout_offset(d), false);
 
         for (idx = 0; idx < vcdinf_get_num_selections(d); idx++)
-          _visit_pbc (obj, 0, vcdinf_psd_get_offset (d, idx), false);
+          _visit_pbc (p_pbc_ctx, 0, vcdinf_psd_get_offset (d, idx), false);
         
       }
       break;
 
     case PSD_TYPE_END_LIST:
-      _cdio_list_append (obj->offset_list, ofs);
+      _cdio_list_append (p_pbc_ctx->offset_list, ofs);
       break;
 
     default:
@@ -753,39 +759,41 @@ _visit_pbc (struct _pbc_ctx *obj, lid_t lid, unsigned int offset, bool in_lot)
 }
 
 static void
-_visit_lot (struct _pbc_ctx *obj)
+_visit_lot (pbc_ctx_t *p_pbc_ctx)
 {
-  const LotVcd_t *lot = obj->lot;
+  const LotVcd_t *lot = p_pbc_ctx->lot;
   unsigned int n, tmp;
 
   for (n = 0; n < LOT_VCD_OFFSETS; n++)
     if ((tmp = vcdinf_get_lot_offset(lot, n)) != PSD_OFS_DISABLED)
-      _visit_pbc (obj, n + 1, tmp, true);
+      _visit_pbc (p_pbc_ctx, n + 1, tmp, true);
 
-  _vcd_list_sort (obj->offset_list, (_cdio_list_cmp_func) vcdinf_lid_t_cmp);
+  _vcd_list_sort (p_pbc_ctx->offset_list, 
+		  (_cdio_list_cmp_func) vcdinf_lid_t_cmp);
 }
 
 static int
-_parse_pbc (struct vcdxml_t *obj, CdIo *img, bool no_ext_psd)
+_parse_pbc (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, bool no_ext_psd)
 {
   int n;
-  struct _pbc_ctx _pctx;
-  CdioListNode *node;
+  pbc_ctx_t _pbc_ctx;
+  CdioListNode_t *node;
   bool extended = false;
   uint32_t _lot_vcd_sector = -1;
   uint32_t _psd_vcd_sector = -1;
   unsigned _psd_size = -1;
   iso9660_stat_t *statbuf;
+  int rc = 0;
 
-  if (!obj->info.psd_size)
+  if (!p_vcdxml->info.psd_size)
     {
       vcd_debug ("No PBC info");
       return 0;
     }
 
-  if (obj->vcd_type == VCD_TYPE_VCD2)
+  if (p_vcdxml->vcd_type == VCD_TYPE_VCD2)
     {
-      statbuf = iso9660_fs_stat (img, "EXT/LOT_X.VCD;1");
+      statbuf = iso9660_fs_stat (p_cdio, "EXT/LOT_X.VCD;1");
       if (statbuf != NULL) {
 	extended = true;
 	_lot_vcd_sector = statbuf->lsn;
@@ -794,7 +802,7 @@ _parse_pbc (struct vcdxml_t *obj, CdIo *img, bool no_ext_psd)
 
       free(statbuf);
       if (extended &&
-	  NULL != (statbuf = iso9660_fs_stat (img, "EXT/PSD_X.VCD;1"))) {
+	  NULL != (statbuf = iso9660_fs_stat (p_cdio, "EXT/PSD_X.VCD;1"))) {
 	_psd_vcd_sector = statbuf->lsn;
 	_psd_size = statbuf->size;
 	free(statbuf);
@@ -802,7 +810,7 @@ _parse_pbc (struct vcdxml_t *obj, CdIo *img, bool no_ext_psd)
 	extended = false;
     }
 
-  _pctx.extended = extended;
+  _pbc_ctx.extended = extended;
 
   if (extended && !no_ext_psd)
     vcd_info ("detected extended VCD2.0 PBC files");
@@ -810,60 +818,71 @@ _parse_pbc (struct vcdxml_t *obj, CdIo *img, bool no_ext_psd)
     if (extended)
       vcd_info ("ignoring detected extended VCD2.0 PBC files");
     
-    _pctx.extended = false;
+    _pbc_ctx.extended = false;
     
     _lot_vcd_sector = LOT_VCD_SECTOR;
     _psd_vcd_sector = PSD_VCD_SECTOR;
-    _psd_size = obj->info.psd_size;
+    _psd_size = p_vcdxml->info.psd_size;
   }
 
-  _pctx.psd_size = _psd_size;
-  _pctx.offset_mult = 8;
-  _pctx.maximum_lid = obj->info.max_lid;
+  _pbc_ctx.psd_size = _psd_size;
+  _pbc_ctx.offset_mult = 8;
+  _pbc_ctx.maximum_lid = p_vcdxml->info.max_lid;
 
-  _pctx.offset_list = _cdio_list_new ();
+  _pbc_ctx.offset_list = _cdio_list_new ();
 
   /* read in LOT */
   
-  _pctx.lot = _vcd_malloc (ISO_BLOCKSIZE * LOT_VCD_SIZE);
+  _pbc_ctx.lot = calloc(1, ISO_BLOCKSIZE * LOT_VCD_SIZE);
   
-  if (cdio_read_mode2_sectors (img, _pctx.lot, _lot_vcd_sector, false, 
-			       LOT_VCD_SIZE))
+  if (cdio_read_mode2_sectors (p_cdio, _pbc_ctx.lot, _lot_vcd_sector, false, 
+			       LOT_VCD_SIZE)) {
+    _cdio_list_free (_pbc_ctx.offset_list, true);
+    free(_pbc_ctx.lot);
     return -1;
+  }
+  
 
   /* read in PSD */
 
   n = _vcd_len2blocks (_psd_size, ISO_BLOCKSIZE);
 
-  _pctx.psd = _vcd_malloc (ISO_BLOCKSIZE * n);
+  _pbc_ctx.psd = calloc(1, ISO_BLOCKSIZE * n);
 
-  if (cdio_read_mode2_sectors (img, _pctx.psd,_psd_vcd_sector, false, n))
-    return -1;
+  if (cdio_read_mode2_sectors (p_cdio, _pbc_ctx.psd,_psd_vcd_sector, false, n)) {
+    rc = -1;
+    goto free_and_return;
+  }
+  
 
   /* traverse it */
 
-  _visit_lot (&_pctx);
+  _visit_lot (&_pbc_ctx);
 
-  _CDIO_LIST_FOREACH (node, _pctx.offset_list)
+  _CDIO_LIST_FOREACH (node, _pbc_ctx.offset_list)
     {
       vcdinfo_offset_t *ofs = _cdio_list_node_data (node);
       pbc_t *_pbc;
 
       vcd_assert (ofs->offset != PSD_OFS_DISABLED);
       
-      if ((_pbc = _pbc_node_read (&_pctx, ofs->offset)))
-	_cdio_list_append (obj->pbc_list, _pbc);
+      if ((_pbc = _pbc_node_read (&_pbc_ctx, ofs->offset)))
+	_cdio_list_append (p_vcdxml->pbc_list, _pbc);
     }
 
+ free_and_return:
+  _cdio_list_free (_pbc_ctx.offset_list, true);
+  free(_pbc_ctx.lot);
+  free(_pbc_ctx.psd);
   return 0;
 }
 
 static int
-_rip_isofs (struct vcdxml_t *obj, CdIo *img)
+_rip_isofs (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   
-  _CDIO_LIST_FOREACH (node, obj->filesystem)
+  _CDIO_LIST_FOREACH (node, p_vcdxml->filesystem)
     {
       struct filesystem_t *_fs = _cdio_list_node_data (node);
       int idx;
@@ -891,7 +910,7 @@ _rip_isofs (struct vcdxml_t *obj, CdIo *img)
 	  /* memset (buf, 0, sizeof (buf)); */
 	  memset (buf, 0, blocksize);
 
-	  cdio_read_mode2_sector (img, buf, _fs->lsn + (idx / blocksize),
+	  cdio_read_mode2_sector (p_cdio, buf, _fs->lsn + (idx / blocksize),
 				  _fs->file_raw);
 
 	  fwrite (buf, blocksize, 1, outfd);
@@ -915,37 +934,38 @@ _rip_isofs (struct vcdxml_t *obj, CdIo *img)
 }
 
 static int
-_rip_segments (struct vcdxml_t *obj, CdIo *img)
+_rip_segments (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   lsn_t start_extent;
 
-  start_extent = obj->info.segments_start;
+  start_extent = p_vcdxml->info.segments_start;
 
   vcd_assert (start_extent % CDIO_CD_FRAMES_PER_SEC == 0);
 
-  _CDIO_LIST_FOREACH (node, obj->segment_list)
+  _CDIO_LIST_FOREACH (node, p_vcdxml->segment_list)
     {
-      struct segment_t *_seg = _cdio_list_node_data (node);
+      struct segment_t *p_seg = _cdio_list_node_data (node);
       uint32_t n;
       FILE *outfd = NULL;
       VcdMpegStreamCtx mpeg_ctx;
       double last_pts = 0;
 
-      vcd_assert (_seg->segments_count > 0);
+      vcd_assert (p_seg->segments_count > 0);
 
       memset (&mpeg_ctx, 0, sizeof (VcdMpegStreamCtx));
 
       vcd_info ("extracting %s... (start lsn %u, %d segments)",
-		_seg->src, (unsigned int) start_extent, _seg->segments_count);
+		p_seg->src, (unsigned int) start_extent, 
+		p_seg->segments_count);
 
-      if (!(outfd = fopen (_seg->src, "wb")))
+      if (!(outfd = fopen (p_seg->src, "wb")))
         {
           perror ("fopen()");
           exit (EXIT_FAILURE);
         }
 
-      for (n = 0; n < _seg->segments_count * VCDINFO_SEGMENT_SECTOR_SIZE; n++)
+      for (n = 0; n < p_seg->segments_count * VCDINFO_SEGMENT_SECTOR_SIZE; n++)
 	{
 	  struct m2f2sector
           {
@@ -956,7 +976,7 @@ _rip_segments (struct vcdxml_t *obj, CdIo *img)
           buf;
 
 	  memset (&buf, 0, sizeof (buf));
-	  cdio_read_mode2_sector (img, &buf, start_extent + n, true);
+	  cdio_read_mode2_sector (p_cdio, &buf, start_extent + n, true);
 	  
 	  if (!buf.subheader[0] 
               && !buf.subheader[1]
@@ -981,12 +1001,12 @@ _rip_segments (struct vcdxml_t *obj, CdIo *img)
 
 	  if (buf.subheader[2] & SM_TRIG)
 	    {
-	      double *_ap_ts = _vcd_malloc (sizeof (double));
+	      double *_ap_ts = calloc(1, sizeof (double));
 	      
 	      vcd_debug ("autopause @%u (%f)", (unsigned int) n, last_pts);
 	      *_ap_ts = last_pts;
 
-	      _cdio_list_append (_seg->autopause_list, _ap_ts);
+	      _cdio_list_append (p_seg->autopause_list, _ap_ts);
 	    }
 
 	  fwrite (buf.data, M2F2_SECTOR_SIZE, 1, outfd);
@@ -1003,22 +1023,22 @@ _rip_segments (struct vcdxml_t *obj, CdIo *img)
 
       fclose (outfd);
 
-      start_extent += _seg->segments_count * VCDINFO_SEGMENT_SECTOR_SIZE;
+      start_extent += p_seg->segments_count * VCDINFO_SEGMENT_SECTOR_SIZE;
     }
 
   return 0;
 }
 
 static int
-_rip_sequences (struct vcdxml_t *obj, CdIo *img, int tracknum)
+_rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   int counter=1;
 
-  _CDIO_LIST_FOREACH (node, obj->sequence_list)
+  _CDIO_LIST_FOREACH (node, p_vcdxml->sequence_list)
     {
       struct sequence_t *_seq = _cdio_list_node_data (node);
-      CdioListNode *nnode = _cdio_list_node_next (node);
+      CdioListNode_t *nnode = _cdio_list_node_next (node);
       struct sequence_t *_nseq = nnode ? _cdio_list_node_data (nnode) : NULL;
       FILE *outfd = NULL;
       bool in_data = false;
@@ -1030,21 +1050,26 @@ _rip_sequences (struct vcdxml_t *obj, CdIo *img, int tracknum)
 
       struct m2f2sector
       {
-	uint8_t subheader[8];
+	uint8_t subheader[CDIO_CD_SUBHEADER_SIZE];
 	uint8_t data[M2F2_SECTOR_SIZE];
 	uint8_t spare[4];
       }
       buf[15];
 
-      if (tracknum && tracknum!=counter++) {
-	vcd_info("Track %d selected, skipping track %d", tracknum,counter-1);
+      if (i_track > 0 && i_track!=counter++) {
+	vcd_info("Track %d selected, skipping track %d", i_track,counter-1);
+	continue;
+      }
+	  
+      if (i_track < 0 && -i_track==counter++) {
+	vcd_info("Skipping track %d", -i_track);
 	continue;
       }
 	  
       memset (&mpeg_ctx, 0, sizeof (VcdMpegStreamCtx));
 
       start_lsn = _seq->start_extent;
-      end_lsn = _nseq ? _nseq->start_extent : cdio_stat_size (img);
+      end_lsn = _nseq ? _nseq->start_extent : cdio_stat_size (p_cdio);
 
       vcd_info ("extracting %s... (start lsn %lu (+%lu))",
 		_seq->src, (long unsigned int) start_lsn, 
@@ -1076,7 +1101,7 @@ _rip_sequences (struct vcdxml_t *obj, CdIo *img, int tracknum)
 	      const int secs_left = end_lsn - n;
 
 	      memset (buf, 0, sizeof (buf));
-	      cdio_read_mode2_sectors (img, buf, n, true, (secs_left > 15 
+	      cdio_read_mode2_sectors (p_cdio, buf, n, true, (secs_left > 15 
 							   ? 15 : secs_left));
 	    }
 
@@ -1123,7 +1148,7 @@ _rip_sequences (struct vcdxml_t *obj, CdIo *img, int tracknum)
 
 	  if (in_data)
 	    {
-	      CdioListNode *_node;
+	      CdioListNode_t *_node;
 
 	      vcd_mpeg_parse_packet (buf[buf_idx].data, M2F2_SECTOR_SIZE, 
 				     false, &mpeg_ctx);
@@ -1146,7 +1171,7 @@ _rip_sequences (struct vcdxml_t *obj, CdIo *img, int tracknum)
 
 	      if (buf[buf_idx].subheader[2] & SM_TRIG)
 		{
-		  double *_ap_ts = _vcd_malloc (sizeof (double));
+		  double *_ap_ts = calloc(1, sizeof (double));
 
 		  vcd_debug ("autopause @%u (%f)", (unsigned int) n, 
 			     last_pts);
@@ -1234,8 +1259,8 @@ _vcd_log_handler (vcd_log_level_t level, const char message[])
 int
 main (int argc, const char *argv[])
 {
-  CdIo *img_src = NULL;
-  struct vcdxml_t obj;
+  CdIo_t *img_src = NULL;
+  vcdxml_t vcdxml;
 
   /* cl params */
   char *xml_fname = NULL;
@@ -1250,6 +1275,9 @@ main (int argc, const char *argv[])
   int _progress_flag = 0;
   int _gui_flag = 0;
   int _track_flag=0;
+  int _x_track_flag=0;
+  bool b_free_xml_fname = false;
+  bool b_free_img_fname = false;
 
   enum { 
     CL_SOURCE_UNDEF = DRIVER_UNKNOWN, 
@@ -1262,7 +1290,7 @@ main (int argc, const char *argv[])
 
   vcd_xml_progname = "vcdxrip";
 
-  vcd_xml_init (&obj);
+  vcd_xml_init (&vcdxml);
 
   gl_default_vcd_log_handler  = vcd_log_set_handler (_vcd_log_handler);
   gl_default_cdio_log_handler = 
@@ -1325,6 +1353,9 @@ main (int argc, const char *argv[])
       { "track", 't', POPT_ARG_INT, &_track_flag, 0,
 	"rip only this track"},
       
+      { "notrack", 'T', POPT_ARG_INT, &_x_track_flag, 0,
+	"do not rip this track"},
+      
       { "filename-encoding", '\0', POPT_ARG_STRING, &vcd_xml_filename_charset, 0,
         "use given charset encoding for filenames instead of UTF8" },
 
@@ -1399,8 +1430,10 @@ main (int argc, const char *argv[])
   if (_progress_flag)
     vcd_xml_show_progress = true;
 
-  if (!xml_fname)
+  if (!xml_fname) {
     xml_fname = strdup (DEFAULT_XML_FNAME);
+    b_free_xml_fname = true;
+  }
 
   /* If we don't specify a driver_id or a source_name, scan the
      system for a CD that contains a VCD.
@@ -1415,6 +1448,7 @@ main (int argc, const char *argv[])
       return VCDINFO_OPEN_ERROR;
     }
     img_fname = strdup(cd_drives[0]);
+    b_free_img_fname = true;
     cdio_free_device_list(cd_drives);
   }
 
@@ -1427,20 +1461,23 @@ main (int argc, const char *argv[])
   if (NULL == img_fname) 
     img_fname = cdio_get_default_device(img_src);
 
-  obj.comment = vcd_xml_dump_cl_comment (argc, argv, nocommand_comment_flag);
+  vcdxml.comment = vcd_xml_dump_cl_comment (argc, argv, 
+					      nocommand_comment_flag);
 
   /* start with ISO9660 PVD */
-  _parse_pvd (&obj, img_src);
+  _parse_pvd (&vcdxml, img_src);
 
-  _parse_isofs (&obj, img_src); 
+  _parse_isofs (&vcdxml, img_src); 
   
   /* needs to be parsed in order */
-  _parse_info (&obj, img_src);
-  _parse_entries (&obj, img_src);
+  _parse_info (&vcdxml, img_src);
+  _parse_entries (&vcdxml, img_src);
 
   /* needs to be parsed last! */
-  _parse_pbc (&obj, img_src, no_ext_psd_flag);
+  _parse_pbc (&vcdxml, img_src, no_ext_psd_flag);
 
+  if (_x_track_flag) _track_flag = - _x_track_flag;
+  
   if (norip_flag || noseq_flag || noseg_flag || _track_flag) {
     vcd_warn ("Entry offsets inside sequence-items may incorrect...");
     vcd_warn ("and auto-pause locations might not be checked.");
@@ -1449,17 +1486,20 @@ main (int argc, const char *argv[])
   if (!norip_flag)
     {
       if (!nofile_flag)
-	_rip_isofs (&obj, img_src);
+	_rip_isofs (&vcdxml, img_src);
 
       if (!noseg_flag)
-	_rip_segments (&obj, img_src);
+	_rip_segments (&vcdxml, img_src);
 
       if (!noseq_flag)
-	_rip_sequences (&obj, img_src, _track_flag);
+	_rip_sequences (&vcdxml, img_src, _track_flag);
     }
 
   vcd_info ("Writing XML description to `%s'...", xml_fname);
-  vcd_xml_dump (&obj, xml_fname);
+  vcd_xml_dump (&vcdxml, xml_fname);
+  vcd_xml_destroy(&vcdxml);
+  if (b_free_xml_fname) free(xml_fname);
+  if (b_free_img_fname) free(img_fname);
 
   cdio_destroy (img_src);
   vcd_info ("done");
