@@ -1,5 +1,5 @@
 /*
-    $Id: image.c,v 1.4 2004/10/10 20:20:19 rocky Exp $
+    $Id: image.c,v 1.5 2005/02/02 00:37:37 rocky Exp $
 
     Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
                   2002 Rocky Bernstein <rocky@panix.com>
@@ -34,7 +34,7 @@
 #include "image_sink.h"
 #include "util.h"
 
-static const char _rcsid[] = "$Id: image.c,v 1.4 2004/10/10 20:20:19 rocky Exp $";
+static const char _rcsid[] = "$Id: image.c,v 1.5 2005/02/02 00:37:37 rocky Exp $";
 
 /*
  * VcdImageSink routines next.
@@ -50,7 +50,7 @@ vcd_image_sink_new (void *user_data, const vcd_image_sink_funcs *funcs)
 {
   VcdImageSink *new_obj;
 
-  new_obj = _vcd_malloc (sizeof (VcdImageSink));
+  new_obj = calloc(1, sizeof (VcdImageSink));
 
   new_obj->user_data = user_data;
   new_obj->op = *funcs;
@@ -68,7 +68,7 @@ vcd_image_sink_destroy (VcdImageSink *obj)
 }
 
 int
-vcd_image_sink_set_cuesheet (VcdImageSink *obj, const CdioList *vcd_cue_list)
+vcd_image_sink_set_cuesheet (VcdImageSink *obj, const CdioList_t *vcd_cue_list)
 {
   vcd_assert (obj != NULL);
 
