@@ -1,5 +1,5 @@
 /*
-    $Id: image_bincue.c,v 1.6 2004/10/25 01:44:51 rocky Exp $
+    $Id: image_bincue.c,v 1.7 2005/02/02 00:37:37 rocky Exp $
 
     Copyright (C) 2001, 2004 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -40,7 +40,7 @@
 #include "stream_stdio.h"
 #include "util.h"
 
-static const char _rcsid[] = "$Id: image_bincue.c,v 1.6 2004/10/25 01:44:51 rocky Exp $";
+static const char _rcsid[] = "$Id: image_bincue.c,v 1.7 2005/02/02 00:37:37 rocky Exp $";
 
 /* reader */
 
@@ -91,7 +91,7 @@ static int
 _set_cuesheet (void *user_data, const CdioList *vcd_cue_list)
 {
   _img_bincue_snk_t *_obj = user_data;
-  CdioListNode *node;
+  CdioListNode_t *node;
   int track_no, index_no;
   const vcd_cue_t *_last_cue = 0;
   
@@ -249,7 +249,7 @@ vcd_image_sink_new_bincue (void)
     .set_arg      = _sink_set_arg
   };
 
-  _data = _vcd_malloc (sizeof (_img_bincue_snk_t));
+  _data = calloc(1, sizeof (_img_bincue_snk_t));
 
   _data->bin_fname = strdup ("videocd.bin");
   _data->cue_fname = strdup ("videocd.cue");
