@@ -1,7 +1,7 @@
 /*
-    $Id: image_nrg.c,v 1.6 2004/10/25 01:44:51 rocky Exp $
+    $Id: image_nrg.c,v 1.7 2005/02/02 00:37:37 rocky Exp $
 
-    Copyright (C) 2001, 2003, 2004 Herbert Valerio Riedel <hvr@gnu.org>
+    Copyright (C) 2001, 2003, 2004, 2005 Herbert Valerio Riedel <hvr@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #include "stream_stdio.h"
 #include "util.h"
 
-static const char _rcsid[] = "$Id: image_nrg.c,v 1.6 2004/10/25 01:44:51 rocky Exp $";
+static const char _rcsid[] = "$Id: image_nrg.c,v 1.7 2005/02/02 00:37:37 rocky Exp $";
 
 /* structures used */
 
@@ -107,7 +107,7 @@ typedef struct {
   VcdDataSink *nrg_snk;
   char *nrg_fname;
 
-  CdioList *vcd_cue_list;
+  CdioList_t *vcd_cue_list;
   int tracks;
   uint32_t cue_end_lsn;
 
@@ -139,10 +139,10 @@ _sink_free (void *user_data)
 }
 
 static int
-_set_cuesheet (void *user_data, const CdioList *vcd_cue_list)
+_set_cuesheet (void *user_data, const CdioList_t *vcd_cue_list)
 {
   _img_nrg_snk_t *_obj = user_data;
-  CdioListNode *node;
+  CdioListNode_t *node;
   int num;
 
   _sink_init (_obj);
@@ -150,10 +150,10 @@ _set_cuesheet (void *user_data, const CdioList *vcd_cue_list)
   _obj->vcd_cue_list = _cdio_list_new ();
 
   num = 0;
-  _CDIO_LIST_FOREACH (node, (CdioList *) vcd_cue_list)
+  _CDIO_LIST_FOREACH (node, (CdioList_t *) vcd_cue_list)
     {
       const vcd_cue_t *_cue = _cdio_list_node_data (node);
-      vcd_cue_t *_cue2 = _vcd_malloc (sizeof (vcd_cue_t));
+      vcd_cue_t *_cue2 = calloc(1, sizeof (vcd_cue_t));
       *_cue2 = *_cue;
       _cdio_list_append (_obj->vcd_cue_list, _cue2);
   
@@ -174,7 +174,7 @@ _set_cuesheet (void *user_data, const CdioList *vcd_cue_list)
 static uint32_t
 _map (_img_nrg_snk_t *_obj, uint32_t lsn)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   uint32_t result = lsn;
   vcd_cue_t *_cue = NULL, *_last = NULL;
 
@@ -226,7 +226,7 @@ _map (_img_nrg_snk_t *_obj, uint32_t lsn)
 static int
 _write_tail (_img_nrg_snk_t *_obj, uint32_t offset)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   int _size;
   _chunk_t _chunk;
 
@@ -341,7 +341,7 @@ vcd_image_sink_new_nrg (void)
     .set_arg      = _sink_set_arg
   };
 
-  _data = _vcd_malloc (sizeof (_img_nrg_snk_t));
+  _data = calloc(1, sizeof (_img_nrg_snk_t));
   _data->nrg_fname = strdup ("videocd.nrg");
 
   vcd_warn ("opening TAO NRG image for writing; TAO (S)VCD are NOT 100%% compliant!");
