@@ -1,7 +1,7 @@
 /*
-    $Id: mpeg_stream.c,v 1.4 2004/10/25 01:44:51 rocky Exp $
+    $Id: mpeg_stream.c,v 1.7 2005/05/08 03:48:55 rocky Exp $
 
-    Copyright (C) 2000, 2004 Herbert Valerio Riedel <hvr@gnu.org>
+    Copyright (C) 2000, 2004, 2005 Herbert Valerio Riedel <hvr@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 
 #include <cdio/cdio.h>
 #include <cdio/bytesex.h>
+#include <cdio/util.h>
 
 #include <libvcd/logging.h>
 
@@ -38,7 +39,7 @@
 #include "mpeg.h"
 #include "util.h"
 
-static const char _rcsid[] = "$Id: mpeg_stream.c,v 1.4 2004/10/25 01:44:51 rocky Exp $";
+static const char _rcsid[] = "$Id: mpeg_stream.c,v 1.7 2005/05/08 03:48:55 rocky Exp $";
 
 struct _VcdMpegSource
 {
@@ -57,14 +58,14 @@ struct _VcdMpegSource
  * access functions
  */
 
-VcdMpegSource *
+VcdMpegSource_t *
 vcd_mpeg_source_new (VcdDataSource *mpeg_file)
 {
-  VcdMpegSource *new_obj;
+  VcdMpegSource_t *new_obj;
   
   vcd_assert (mpeg_file != NULL);
 
-  new_obj = _vcd_malloc (sizeof (VcdMpegSource));
+  new_obj = calloc(1, sizeof (VcdMpegSource_t));
 
   new_obj->data_source = mpeg_file;
   new_obj->scanned = false;
@@ -73,7 +74,7 @@ vcd_mpeg_source_new (VcdDataSource *mpeg_file)
 }
 
 void
-vcd_mpeg_source_destroy (VcdMpegSource *obj, bool destroy_file_obj)
+vcd_mpeg_source_destroy (VcdMpegSource_t *obj, bool destroy_file_obj)
 {
   int i;
   vcd_assert (obj != NULL);
@@ -89,7 +90,7 @@ vcd_mpeg_source_destroy (VcdMpegSource *obj, bool destroy_file_obj)
 }
 
 const struct vcd_mpeg_stream_info *
-vcd_mpeg_source_get_info (VcdMpegSource *obj)
+vcd_mpeg_source_get_info (VcdMpegSource_t *obj)
 {
   vcd_assert (obj != NULL);
 
@@ -99,7 +100,7 @@ vcd_mpeg_source_get_info (VcdMpegSource *obj)
 }
 
 long
-vcd_mpeg_source_stat (VcdMpegSource *obj)
+vcd_mpeg_source_stat (VcdMpegSource_t *obj)
 {
   vcd_assert (obj != NULL);
   vcd_assert (!obj->scanned);
@@ -108,7 +109,7 @@ vcd_mpeg_source_stat (VcdMpegSource *obj)
 }
 
 void
-vcd_mpeg_source_scan (VcdMpegSource *obj, bool strict_aps, bool fix_scan_info,
+vcd_mpeg_source_scan (VcdMpegSource_t *obj, bool strict_aps, bool fix_scan_info,
                       vcd_mpeg_prog_cb_t callback, void *user_data)
 {
   unsigned length = 0;
@@ -117,7 +118,7 @@ vcd_mpeg_source_scan (VcdMpegSource *obj, bool strict_aps, bool fix_scan_info,
   unsigned padbytes = 0;
   unsigned padpackets = 0;
   VcdMpegStreamCtx state;
-  CdioListNode *n;
+  CdioListNode_t *n;
   vcd_mpeg_prog_info_t _progress = { 0, };
 
   vcd_assert (obj != NULL);
@@ -151,7 +152,7 @@ vcd_mpeg_source_scan (VcdMpegSource *obj, bool strict_aps, bool fix_scan_info,
       int read_len = MIN (sizeof (buf), (length - pos));
       int pkt_len;
 
-      vcd_data_source_read (obj->data_source, buf, read_len, 1);
+      read_len = vcd_data_source_read (obj->data_source, buf, read_len, 1);
 
       pkt_len = vcd_mpeg_parse_packet (buf, read_len, true, &state);
 
@@ -188,13 +189,14 @@ vcd_mpeg_source_scan (VcdMpegSource *obj, bool strict_aps, bool fix_scan_info,
         case APS_SGI:
         case APS_ASGI:
           {
-            struct aps_data *_data = _vcd_malloc (sizeof (struct aps_data));
+            struct aps_data *_data = calloc(1, sizeof (struct aps_data));
             
             _data->packet_no = pno;
             _data->timestamp = state.packet.aps_pts;
 
             if (!state.stream.shdr[state.packet.aps_idx].aps_list)
-              state.stream.shdr[state.packet.aps_idx].aps_list = _cdio_list_new ();
+              state.stream.shdr[state.packet.aps_idx].aps_list = 
+                _cdio_list_new ();
             
             _cdio_list_append (state.stream.shdr[state.packet.aps_idx].aps_list, _data);
           }
@@ -271,7 +273,7 @@ static double
 _approx_pts (CdioList *aps_list, uint32_t packet_no)
 {
   double retval = 0;
-  CdioListNode *node;
+  CdioListNode_t *node;
 
   struct aps_data *_laps = NULL;
 
@@ -324,7 +326,7 @@ static void
 _fix_scan_info (struct vcd_mpeg_scan_data_t *scan_data_ptr,
                 unsigned packet_no, double pts, CdioList *aps_list)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   long _next = -1, _prev = -1, _forw = -1, _back = -1;
 
   _CDIO_LIST_FOREACH (node, aps_list)
@@ -363,8 +365,9 @@ _fix_scan_info (struct vcd_mpeg_scan_data_t *scan_data_ptr,
 }
 
 int
-vcd_mpeg_source_get_packet (VcdMpegSource *obj, unsigned long packet_no,
-			    void *packet_buf, struct vcd_mpeg_packet_info *flags,
+vcd_mpeg_source_get_packet (VcdMpegSource_t *obj, unsigned long packet_no,
+			    void *packet_buf, 
+                            struct vcd_mpeg_packet_info *flags,
                             bool fix_scan_info)
 {
   unsigned length;
@@ -437,7 +440,8 @@ vcd_mpeg_source_get_packet (VcdMpegSource *obj, unsigned long packet_no,
               if (state.packet.has_pts)
                 _pts = state.packet.pts - obj->info.min_pts;
               else
-                _pts = _approx_pts (obj->info.shdr[vid_idx].aps_list, packet_no);
+                _pts = _approx_pts (obj->info.shdr[vid_idx].aps_list, 
+                                    packet_no);
 
               _fix_scan_info (state.packet.scan_data_ptr, packet_no, 
                               _pts, obj->info.shdr[vid_idx].aps_list);
@@ -464,17 +468,17 @@ vcd_mpeg_source_get_packet (VcdMpegSource *obj, unsigned long packet_no,
 
   vcd_assert (pos == length);
 
-  vcd_error ("shouldnt be reached...");
+  vcd_error ("shouldn't be reached...");
 
   return -1;
 }
 
 void
-vcd_mpeg_source_close (VcdMpegSource *obj)
+vcd_mpeg_source_close (VcdMpegSource_t *p_vcdmpegsource)
 {
-  vcd_assert (obj != NULL);
+  vcd_assert (p_vcdmpegsource != NULL);
 
-  vcd_data_source_close (obj->data_source);
+  vcd_data_source_close (p_vcdmpegsource->data_source);
 }
 
 
