@@ -1,5 +1,5 @@
 /*
-    $Id: obj.h,v 1.3 2004/10/10 20:20:19 rocky Exp $
+    $Id: obj.h,v 1.6 2005/05/08 03:48:55 rocky Exp $
 
     Copyright (C) 2000 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -44,14 +44,14 @@ typedef struct {
 } pause_t;
 
 typedef struct {
-  VcdMpegSource *source;
+  VcdMpegSource_t *source;
   char *id;
   const struct vcd_mpeg_stream_info *info;
 
-  CdioList *pause_list; /* pause_t */
+  CdioList_t *pause_list; /* pause_t */
 
   char *default_entry_id;
-  CdioList *entry_list; /* entry_t */
+  CdioList_t *entry_list; /* entry_t */
 
   /* pbc ref check */
   bool referenced;
@@ -65,11 +65,11 @@ typedef struct {
 #define mpeg_track_list mpeg_sequence_list 
 
 typedef struct {
-  VcdMpegSource *source;
+  VcdMpegSource_t *source;
   char *id;
   const struct vcd_mpeg_stream_info *info;
 
-  CdioList *pause_list; /* pause_t */
+  CdioList_t *pause_list; /* pause_t */
 
   /* pbc ref check */
   bool referenced;
@@ -128,30 +128,30 @@ struct _VcdObj {
 
   /* input */
   unsigned mpeg_segment_start_extent;
-  CdioList *mpeg_segment_list; /* mpeg_segment_t */
+  CdioList_t *mpeg_segment_list; /* mpeg_segment_t */
 
-  CdioList *mpeg_sequence_list; /* mpeg_sequence_t */
+  CdioList_t *mpeg_sequence_list; /* mpeg_sequence_t */
 
   unsigned relative_end_extent; /* last mpeg sequence track end extent */
 
   /* PBC */
-  CdioList *pbc_list; /* pbc_t */
+  CdioList_t *pbc_list; /* pbc_t */
   unsigned psd_size;
   unsigned psdx_size;
 
   /* custom files */
   unsigned ext_file_start_extent; 
   unsigned custom_file_start_extent; 
-  CdioList *custom_file_list; /* custom_file_t */
-  CdioList *custom_dir_list; /* char */
+  CdioList_t *custom_file_list; /* custom_file_t */
+  CdioList_t *custom_dir_list; /* char */
 
   /* dictionary */
-  CdioList *buffer_dict_list;
+  CdioList_t *buffer_dict_list;
 
   /* aggregates */
   VcdSalloc *iso_bitmap;
 
-  VcdDirectory *dir;
+  VcdDirectory_t *dir;
 
   /* state info */
   bool in_output;
@@ -168,13 +168,13 @@ struct _VcdObj {
 /* private functions */
 
 mpeg_sequence_t *
-_vcd_obj_get_sequence_by_id (VcdObj *obj, const char sequence_id[]);
+_vcd_obj_get_sequence_by_id (VcdObj_t *obj, const char sequence_id[]);
 
 mpeg_sequence_t *
-_vcd_obj_get_sequence_by_entry_id (VcdObj *obj, const char entry_id[]);
+_vcd_obj_get_sequence_by_entry_id (VcdObj_t *obj, const char entry_id[]);
 
 mpeg_segment_t *
-_vcd_obj_get_segment_by_id (VcdObj *obj, const char segment_id[]);
+_vcd_obj_get_segment_by_id (VcdObj_t *obj, const char segment_id[]);
 
 enum vcd_capability_t {
   _CAP_VALID,
@@ -188,7 +188,7 @@ enum vcd_capability_t {
 };
 
 bool
-_vcd_obj_has_cap_p (const VcdObj *obj, enum vcd_capability_t capability);
+_vcd_obj_has_cap_p (const VcdObj_t *obj, enum vcd_capability_t capability);
 
 #endif /* __VCD_OBJ_H__ */
 
