@@ -1,7 +1,7 @@
 /*
-    $Id: pbc.c,v 1.6 2004/10/25 01:44:51 rocky Exp $
+    $Id: pbc.c,v 1.10 2005/05/08 03:48:55 rocky Exp $
 
-    Copyright (C) 2000, 2004 Herbert Valerio Riedel <hvr@gnu.org>
+    Copyright (C) 2000, 2004, 2005 Herbert Valerio Riedel <hvr@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 
 #include <cdio/cdio.h>
 #include <cdio/bytesex.h>
+#include <cdio/util.h>
 
 /* Public headers */
 #include <libvcd/logging.h>
@@ -44,7 +45,7 @@
 #include "pbc.h"
 #include "util.h"
 
-static const char _rcsid[] = "$Id: pbc.c,v 1.6 2004/10/25 01:44:51 rocky Exp $";
+static const char _rcsid[] = "$Id: pbc.c,v 1.10 2005/05/08 03:48:55 rocky Exp $";
 
 static uint8_t
 _wtime (int seconds)
@@ -73,13 +74,13 @@ _wtime (int seconds)
 }
 
 static pbc_t *
-_vcd_pbc_byid(const VcdObj *obj, const char item_id[])
+_vcd_pbc_byid(const VcdObj_t *obj, const char item_id[])
 {
-  CdioListNode *node;
+  CdioListNode_t *p_node;
 
-  _CDIO_LIST_FOREACH (node, obj->pbc_list)
+  _CDIO_LIST_FOREACH (p_node, obj->pbc_list)
     {
-      pbc_t *_pbc = _cdio_list_node_data (node);
+      pbc_t *_pbc = _cdio_list_node_data (p_node);
 
       if (_pbc->id && !strcmp (item_id, _pbc->id))
 	return _pbc;
@@ -90,14 +91,14 @@ _vcd_pbc_byid(const VcdObj *obj, const char item_id[])
 }
 
 unsigned
-_vcd_pbc_lid_lookup (const VcdObj *obj, const char item_id[])
+_vcd_pbc_lid_lookup (const VcdObj_t *obj, const char item_id[])
 {
-  CdioListNode *node;
+  CdioListNode_t *p_node;
   unsigned n = 1;
 
-  _CDIO_LIST_FOREACH (node, obj->pbc_list)
+  _CDIO_LIST_FOREACH (p_node, obj->pbc_list)
     {
-      pbc_t *_pbc = _cdio_list_node_data (node);
+      pbc_t *_pbc = _cdio_list_node_data (p_node);
 
       vcd_assert (n < 0x8000);
 
@@ -134,7 +135,7 @@ _set_area_helper (pbc_area_t *dest, const pbc_area_t *src, const char sel_id[])
 }
 
 enum item_type_t
-_vcd_pbc_lookup (const VcdObj *obj, const char item_id[])
+_vcd_pbc_lookup (const VcdObj_t *obj, const char item_id[])
 {
   unsigned id;
 
@@ -160,10 +161,10 @@ _vcd_pbc_lookup (const VcdObj *obj, const char item_id[])
 }
 
 uint16_t
-_vcd_pbc_pin_lookup (const VcdObj *obj, const char item_id[])
+_vcd_pbc_pin_lookup (const VcdObj_t *obj, const char item_id[])
 {
   int n;
-  CdioListNode *node;
+  CdioListNode_t *p_node;
 
   if (!item_id)
     return 0;
@@ -171,9 +172,9 @@ _vcd_pbc_pin_lookup (const VcdObj *obj, const char item_id[])
   /* check sequence items */
 
   n = 0;
-  _CDIO_LIST_FOREACH (node, obj->mpeg_sequence_list)
+  _CDIO_LIST_FOREACH (p_node, obj->mpeg_sequence_list)
     {
-      mpeg_sequence_t *_sequence = _cdio_list_node_data (node);
+      mpeg_sequence_t *_sequence = _cdio_list_node_data (p_node);
 
       vcd_assert (n < 98);
 
@@ -186,10 +187,10 @@ _vcd_pbc_pin_lookup (const VcdObj *obj, const char item_id[])
   /* check entry points */
 
   n = 0;
-  _CDIO_LIST_FOREACH (node, obj->mpeg_sequence_list)
+  _CDIO_LIST_FOREACH (p_node, obj->mpeg_sequence_list)
     {
-      mpeg_sequence_t *_sequence = _cdio_list_node_data (node);
-      CdioListNode *node2;
+      mpeg_sequence_t *_sequence = _cdio_list_node_data (p_node);
+      CdioListNode_t *p_node2;
 
       /* default entry point */
 
@@ -200,9 +201,9 @@ _vcd_pbc_pin_lookup (const VcdObj *obj, const char item_id[])
 
       /* additional entry points */
 
-      _CDIO_LIST_FOREACH (node2, _sequence->entry_list)
+      _CDIO_LIST_FOREACH (p_node2, _sequence->entry_list)
 	{
-	  entry_t *_entry = _cdio_list_node_data (node2);
+	  entry_t *_entry = _cdio_list_node_data (p_node2);
 
 	  vcd_assert (n < 500);
 
@@ -216,9 +217,9 @@ _vcd_pbc_pin_lookup (const VcdObj *obj, const char item_id[])
   /* check sequence items */
 
   n = 0;
-  _CDIO_LIST_FOREACH (node, obj->mpeg_segment_list)
+  _CDIO_LIST_FOREACH (p_node, obj->mpeg_segment_list)
     {
-      mpeg_segment_t *_segment = _cdio_list_node_data (node);
+      mpeg_segment_t *_segment = _cdio_list_node_data (p_node);
 
       vcd_assert (n < 1980);
 
@@ -232,7 +233,7 @@ _vcd_pbc_pin_lookup (const VcdObj *obj, const char item_id[])
 }
 
 bool
-_vcd_pbc_available (const VcdObj *obj)
+_vcd_pbc_available (const VcdObj_t *obj)
 {
   vcd_assert (obj != NULL);
   vcd_assert (obj->pbc_list != NULL);
@@ -250,7 +251,7 @@ _vcd_pbc_available (const VcdObj *obj)
 }
 
 uint16_t
-_vcd_pbc_max_lid (const VcdObj *obj)
+_vcd_pbc_max_lid (const VcdObj_t *obj)
 {
   uint16_t retval = 0;
   
@@ -261,33 +262,33 @@ _vcd_pbc_max_lid (const VcdObj *obj)
 }
 
 static size_t
-_vcd_pbc_node_length (const VcdObj *obj, const pbc_t *_pbc, bool extended)
+_vcd_pbc_node_length (const VcdObj_t *obj, const pbc_t *p_pbc, bool extended)
 {
   size_t retval = 0;
 
   if (extended)
     vcd_assert (_vcd_obj_has_cap_p (obj, _CAP_PBC_X));
 
-  switch (_pbc->type)
+  switch (p_pbc->type)
     {
       int n;
 
     case PBC_PLAYLIST:
-      n = _cdio_list_length (_pbc->item_id_list);
+      n = _cdio_list_length (p_pbc->item_id_list);
       retval = __cd_offsetof (_PsdPlayListDescriptor, itemid[n]);
       break;
 
     case PBC_SELECTION:
-      n = _cdio_list_length (_pbc->select_id_list);
+      n = _cdio_list_length (p_pbc->select_id_list);
 
       retval = __cd_offsetof (PsdSelectionListDescriptor_t, ofs[n]);
 
       if (extended || _vcd_obj_has_cap_p (obj, _CAP_4C_SVCD))
-	retval += __cd_offsetof (PsdSelectionListDescriptorExtended, area[n]);
+	retval += __cd_offsetof (PsdSelectionListDescriptorExtended_t, area[n]);
       break;
       
     case PBC_END:
-      retval = sizeof (PsdEndListDescriptor);
+      retval = sizeof (PsdEndListDescriptor_t);
       break;
 
     default:
@@ -299,9 +300,9 @@ _vcd_pbc_node_length (const VcdObj *obj, const pbc_t *_pbc, bool extended)
 }
 
 static uint16_t 
-_lookup_psd_offset (const VcdObj *obj, const char item_id[], bool extended)
+_lookup_psd_offset (const VcdObj_t *obj, const char item_id[], bool extended)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
 
   if (extended)
     vcd_assert (_vcd_obj_has_cap_p (obj, _CAP_PBC_X));
@@ -312,12 +313,12 @@ _lookup_psd_offset (const VcdObj *obj, const char item_id[], bool extended)
 
   _CDIO_LIST_FOREACH (node, obj->pbc_list)
     {
-      pbc_t *_pbc = _cdio_list_node_data (node);
+      pbc_t *p_pbc = _cdio_list_node_data (node);
 
-      if (!_pbc->id || strcmp (item_id, _pbc->id))
+      if (!p_pbc->id || strcmp (item_id, p_pbc->id))
 	continue;
 	
-      return (extended ? _pbc->offset_ext : _pbc->offset) / INFO_OFFSET_MULT;
+      return (extended ? p_pbc->offset_ext : p_pbc->offset) / INFO_OFFSET_MULT;
     }
 
   vcd_error ("PSD: referenced PSD '%s' not found", item_id);
@@ -327,7 +328,7 @@ _lookup_psd_offset (const VcdObj *obj, const char item_id[], bool extended)
 }
 
 static void
-_vcd_pin_mark_id (const VcdObj *obj, const char _id[])
+_vcd_pin_mark_id (const VcdObj_t *obj, const char _id[])
 {
   mpeg_sequence_t *_seq;
   mpeg_segment_t *_seg;
@@ -337,44 +338,44 @@ _vcd_pin_mark_id (const VcdObj *obj, const char _id[])
   if (!_id)
     return;
 
-  if ((_seq = _vcd_obj_get_sequence_by_id ((VcdObj *) obj, _id)))
+  if ((_seq = _vcd_obj_get_sequence_by_id ((VcdObj_t *) obj, _id)))
     _seq->referenced = true;
 
-  if ((_seg = _vcd_obj_get_segment_by_id ((VcdObj *) obj, _id)))
+  if ((_seg = _vcd_obj_get_segment_by_id ((VcdObj_t *) obj, _id)))
     _seg->referenced = true;
 }
 
 static void
-_vcd_pbc_mark_id (const VcdObj *obj, const char _id[])
+_vcd_pbc_mark_id (const VcdObj_t *obj, const char _id[])
 {
-  pbc_t *_pbc;
+  pbc_t *p_pbc;
 
   vcd_assert (obj != NULL);
 
   if (!_id)
     return;
 
-  _pbc = _vcd_pbc_byid (obj, _id);
+  p_pbc = _vcd_pbc_byid (obj, _id);
 
-  if (!_pbc) /* not found */
+  if (!p_pbc) /* not found */
     return;
 
-  if (_pbc->referenced) /* already marked */
+  if (p_pbc->referenced) /* already marked */
     return;
 
-  _pbc->referenced = true;
+  p_pbc->referenced = true;
 
-  switch (_pbc->type)
+  switch (p_pbc->type)
     {
     case PBC_PLAYLIST:
       {
-	CdioListNode *node;
+	CdioListNode_t *node;
 	
-	_vcd_pbc_mark_id (obj, _pbc->prev_id);
-	_vcd_pbc_mark_id (obj, _pbc->next_id);
-	_vcd_pbc_mark_id (obj, _pbc->retn_id);
+	_vcd_pbc_mark_id (obj, p_pbc->prev_id);
+	_vcd_pbc_mark_id (obj, p_pbc->next_id);
+	_vcd_pbc_mark_id (obj, p_pbc->retn_id);
 
-	_CDIO_LIST_FOREACH (node, _pbc->item_id_list)
+	_CDIO_LIST_FOREACH (node, p_pbc->item_id_list)
 	  {
 	    const char *_id = _cdio_list_node_data (node);
 
@@ -385,20 +386,20 @@ _vcd_pbc_mark_id (const VcdObj *obj, const char _id[])
 
     case PBC_SELECTION:
       {
-	CdioListNode *node;
+	CdioListNode_t *node;
 
-	_vcd_pbc_mark_id (obj, _pbc->prev_id);
-	_vcd_pbc_mark_id (obj, _pbc->next_id);
-	_vcd_pbc_mark_id (obj, _pbc->retn_id);
+	_vcd_pbc_mark_id (obj, p_pbc->prev_id);
+	_vcd_pbc_mark_id (obj, p_pbc->next_id);
+	_vcd_pbc_mark_id (obj, p_pbc->retn_id);
 	
-	if (_pbc->selection_type == _SEL_NORMAL)
-	  _vcd_pbc_mark_id (obj, _pbc->default_id);
+	if (p_pbc->selection_type == _SEL_NORMAL)
+	  _vcd_pbc_mark_id (obj, p_pbc->default_id);
 
-	_vcd_pbc_mark_id (obj, _pbc->timeout_id);
+	_vcd_pbc_mark_id (obj, p_pbc->timeout_id);
 
-	_vcd_pin_mark_id (obj, _pbc->item_id);
+	_vcd_pin_mark_id (obj, p_pbc->item_id);
 
-	_CDIO_LIST_FOREACH (node, _pbc->select_id_list)
+	_CDIO_LIST_FOREACH (node, p_pbc->select_id_list)
 	  {
 	    const char *_id = _cdio_list_node_data (node);
 
@@ -408,7 +409,7 @@ _vcd_pbc_mark_id (const VcdObj *obj, const char _id[])
       break;
 
     case PBC_END:
-      _vcd_pin_mark_id (obj, _pbc->image_id);
+      _vcd_pin_mark_id (obj, p_pbc->image_id);
       break;
 
     default:
@@ -418,27 +419,27 @@ _vcd_pbc_mark_id (const VcdObj *obj, const char _id[])
 }
 
 void
-_vcd_pbc_check_unreferenced (const VcdObj *obj)
+_vcd_pbc_check_unreferenced (const VcdObj_t *p_VcdObj)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
 
   /* clear all flags */
 
-  _CDIO_LIST_FOREACH (node, obj->pbc_list)
+  _CDIO_LIST_FOREACH (node, p_VcdObj->pbc_list)
     {
       pbc_t *_pbc = _cdio_list_node_data (node);
 
       _pbc->referenced = false;
     }
 
-  _CDIO_LIST_FOREACH (node, obj->mpeg_sequence_list)
+  _CDIO_LIST_FOREACH (node, p_VcdObj->mpeg_sequence_list)
     {
       mpeg_sequence_t *_sequence = _cdio_list_node_data (node);
 
       _sequence->referenced = false;
     }
 
-  _CDIO_LIST_FOREACH (node, obj->mpeg_segment_list)
+  _CDIO_LIST_FOREACH (node, p_VcdObj->mpeg_segment_list)
     {
       mpeg_segment_t *_segment = _cdio_list_node_data (node);
 
@@ -447,7 +448,7 @@ _vcd_pbc_check_unreferenced (const VcdObj *obj)
 
   /* start from non-rejected lists */
 
-  _CDIO_LIST_FOREACH (node, obj->pbc_list)
+  _CDIO_LIST_FOREACH (node, p_VcdObj->pbc_list)
     {
       pbc_t *_pbc = _cdio_list_node_data (node);
 
@@ -456,12 +457,12 @@ _vcd_pbc_check_unreferenced (const VcdObj *obj)
       if (_pbc->rejected)
 	continue;
 
-      _vcd_pbc_mark_id (obj, _pbc->id);
+      _vcd_pbc_mark_id (p_VcdObj, _pbc->id);
     }
 
   /* collect flags */
 
-  _CDIO_LIST_FOREACH (node, obj->pbc_list)
+  _CDIO_LIST_FOREACH (node, p_VcdObj->pbc_list)
     {
       pbc_t *_pbc = _cdio_list_node_data (node);
 
@@ -469,7 +470,7 @@ _vcd_pbc_check_unreferenced (const VcdObj *obj)
 	vcd_warn ("PSD item '%s' is unreachable", _pbc->id);
     }
 
-  _CDIO_LIST_FOREACH (node, obj->mpeg_sequence_list)
+  _CDIO_LIST_FOREACH (node, p_VcdObj->mpeg_sequence_list)
     {
       mpeg_sequence_t *_sequence = _cdio_list_node_data (node);
 
@@ -477,7 +478,7 @@ _vcd_pbc_check_unreferenced (const VcdObj *obj)
 	vcd_warn ("sequence '%s' is not reachable by PBC", _sequence->id);
     }
 
-  _CDIO_LIST_FOREACH (node, obj->mpeg_segment_list)
+  _CDIO_LIST_FOREACH (node, p_VcdObj->mpeg_segment_list)
     {
       mpeg_segment_t *_segment = _cdio_list_node_data (node);
 
@@ -488,42 +489,42 @@ _vcd_pbc_check_unreferenced (const VcdObj *obj)
 }
 
 void
-_vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
+_vcd_pbc_node_write (const VcdObj_t *obj, const pbc_t *p_pbc, void *buf,
 		     bool extended)
 {
   vcd_assert (obj != NULL);
-  vcd_assert (_pbc != NULL);
+  vcd_assert (p_pbc != NULL);
   vcd_assert (buf != NULL);
 
   if (extended)
     vcd_assert (_vcd_obj_has_cap_p (obj, _CAP_PBC_X));
 
-  switch (_pbc->type)
+  switch (p_pbc->type)
     {
     case PBC_PLAYLIST:
       {
 	_PsdPlayListDescriptor *_md = buf;
-	CdioListNode *node;
+	CdioListNode_t *node;
 	int n;
 	
 	_md->type = PSD_TYPE_PLAY_LIST;
-	_md->noi = _cdio_list_length (_pbc->item_id_list);
+	_md->noi = _cdio_list_length (p_pbc->item_id_list);
 	
-	vcd_assert (_pbc->lid < 0x8000);
-	_md->lid = uint16_to_be (_pbc->lid | (_pbc->rejected ? 0x8000 : 0));
+	vcd_assert (p_pbc->lid < 0x8000);
+	_md->lid = uint16_to_be (p_pbc->lid | (p_pbc->rejected ? 0x8000 : 0));
 	
 	_md->prev_ofs = 
-	  uint16_to_be (_lookup_psd_offset (obj, _pbc->prev_id, extended));
+	  uint16_to_be (_lookup_psd_offset (obj, p_pbc->prev_id, extended));
 	_md->next_ofs = 
-	  uint16_to_be (_lookup_psd_offset (obj, _pbc->next_id, extended));
+	  uint16_to_be (_lookup_psd_offset (obj, p_pbc->next_id, extended));
 	_md->return_ofs =
-	  uint16_to_be (_lookup_psd_offset (obj, _pbc->retn_id, extended));
-	_md->ptime = uint16_to_be (rint (_pbc->playing_time * 15.0));
-	_md->wtime = _wtime (_pbc->wait_time);
-	_md->atime = _wtime (_pbc->auto_pause_time);
+	  uint16_to_be (_lookup_psd_offset (obj, p_pbc->retn_id, extended));
+	_md->ptime = uint16_to_be (rint (p_pbc->playing_time * 15.0));
+	_md->wtime = _wtime (p_pbc->wait_time);
+	_md->atime = _wtime (p_pbc->auto_pause_time);
 	
 	n = 0;
-	_CDIO_LIST_FOREACH (node, _pbc->item_id_list)
+	_CDIO_LIST_FOREACH (node, p_pbc->item_id_list)
 	  {
 	    const char *_id = _cdio_list_node_data (node);
 	    uint16_t _pin;
@@ -549,29 +550,29 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
       {
 	PsdSelectionListDescriptor_t *_md = buf;
 
-	const unsigned int _nos = _cdio_list_length (_pbc->select_id_list);
+	const unsigned int _nos = _cdio_list_length (p_pbc->select_id_list);
 
 	if (extended)
 	  _md->type = PSD_TYPE_EXT_SELECTION_LIST;
 	else
 	  _md->type = PSD_TYPE_SELECTION_LIST;
 
-	if (!IN (_pbc->bsn, 1, MAX_PBC_SELECTIONS))
+	if (!IN (p_pbc->bsn, 1, MAX_PBC_SELECTIONS))
 	  vcd_error ("selection '%s': BSN (%d) not in range [1..%d]",
-		     _pbc->id, _pbc->bsn, MAX_PBC_SELECTIONS);
+		     p_pbc->id, p_pbc->bsn, MAX_PBC_SELECTIONS);
 
 	if (!IN (_nos, 0, MAX_PBC_SELECTIONS))
 	  vcd_error ("selection '%s': too many selections (%d > %d)",
-		     _pbc->id, _nos, MAX_PBC_SELECTIONS);
+		     p_pbc->id, _nos, MAX_PBC_SELECTIONS);
 
-	if (_nos + _pbc->bsn > 100)
+	if (_nos + p_pbc->bsn > 100)
 	  vcd_error ("selection '%s': BSN + NOS (%d + %d) > 100",
-		     _pbc->id, _pbc->bsn, _nos);
+		     p_pbc->id, p_pbc->bsn, _nos);
 
-	_md->bsn = _pbc->bsn;
+	_md->bsn = p_pbc->bsn;
 	_md->nos = _nos;
 
-	vcd_assert (sizeof (PsdSelectionListFlags) == 1);
+	vcd_assert (sizeof (PsdSelectionListFlags_t) == 1);
 
 	/* selection flags */
 	if (_vcd_obj_has_cap_p (obj, _CAP_4C_SVCD))
@@ -581,35 +582,35 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
 
 	_md->flags.CommandListFlag = false;
 
-	vcd_assert (_pbc->lid < 0x8000);
-	_md->lid = uint16_to_be (_pbc->lid | (_pbc->rejected ? 0x8000 : 0));
+	vcd_assert (p_pbc->lid < 0x8000);
+	_md->lid = uint16_to_be (p_pbc->lid | (p_pbc->rejected ? 0x8000 : 0));
 
 	_md->prev_ofs = 
-	  uint16_to_be (_lookup_psd_offset (obj, _pbc->prev_id, extended));
+	  uint16_to_be (_lookup_psd_offset (obj, p_pbc->prev_id, extended));
 	_md->next_ofs = 
-	  uint16_to_be (_lookup_psd_offset (obj, _pbc->next_id, extended));
+	  uint16_to_be (_lookup_psd_offset (obj, p_pbc->next_id, extended));
 	_md->return_ofs =
-	  uint16_to_be (_lookup_psd_offset (obj, _pbc->retn_id, extended));
+	  uint16_to_be (_lookup_psd_offset (obj, p_pbc->retn_id, extended));
 
-	switch (_pbc->selection_type)
+	switch (p_pbc->selection_type)
 	  {
 	  case _SEL_NORMAL:
 	    _md->default_ofs =
-	      uint16_to_be (_lookup_psd_offset (obj, _pbc->default_id, extended));
+	      uint16_to_be (_lookup_psd_offset (obj, p_pbc->default_id, extended));
 	    break;
 	    
 	  case _SEL_MULTI_DEF:
 	    _md->default_ofs = uint16_to_be (PSD_OFS_MULTI_DEF);
-	    if (_pbc->default_id)
+	    if (p_pbc->default_id)
 	      vcd_warn ("ignoring default target '%s' for multi default selection '%s'",
-			_pbc->default_id, _pbc->id);
+			p_pbc->default_id, p_pbc->id);
 	    break;
 
 	  case _SEL_MULTI_DEF_NO_NUM:
 	    _md->default_ofs = uint16_to_be (PSD_OFS_MULTI_DEF_NO_NUM);
-	    if (_pbc->default_id)
+	    if (p_pbc->default_id)
 	      vcd_warn ("ignoring default target '%s' for multi default (w/o num) selection '%s'",
-			_pbc->default_id, _pbc->id);
+			p_pbc->default_id, p_pbc->id);
 	    break;
 	    
 	  default:
@@ -618,33 +619,33 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
 	  }
 
 	_md->timeout_ofs =
-	  uint16_to_be (_lookup_psd_offset (obj, _pbc->timeout_id, extended));
-	_md->totime = _wtime (_pbc->timeout_time);
+	  uint16_to_be (_lookup_psd_offset (obj, p_pbc->timeout_id, extended));
+	_md->totime = _wtime (p_pbc->timeout_time);
 
-	if (_pbc->loop_count > 0x7f)
-	  vcd_warn ("loop count %d > 127", _pbc->loop_count);
+	if (p_pbc->loop_count > 0x7f)
+	  vcd_warn ("loop count %d > 127", p_pbc->loop_count);
 
-	_md->loop = (_pbc->loop_count > 0x7f) ? 0x7f : _pbc->loop_count;
+	_md->loop = (p_pbc->loop_count > 0x7f) ? 0x7f : p_pbc->loop_count;
 	
-	if (_pbc->jump_delayed)
+	if (p_pbc->jump_delayed)
 	  _md->loop |= 0x80;
 
 	/* timeout related sanity checks */
-	if (_pbc->loop_count > 0
-	    && _pbc->timeout_time >= 0
-	    && !_pbc->timeout_id
+	if (p_pbc->loop_count > 0
+	    && p_pbc->timeout_time >= 0
+	    && !p_pbc->timeout_id
 	    && !_nos)
-	  vcd_warn ("PSD: selection '%s': neither timeout nor select target available, but neither loop count is infinite nor timeout wait time", _pbc->id);
+	  vcd_warn ("PSD: selection '%s': neither timeout nor select target available, but neither loop count is infinite nor timeout wait time", p_pbc->id);
 
-	if (_pbc->timeout_id && (_pbc->timeout_time < 0 || _pbc->loop_count <= 0))
-	  vcd_warn ("PSD: selection '%s': timeout target '%s' is never used due to loop count or timeout wait time given", _pbc->id, _pbc->timeout_id);
+	if (p_pbc->timeout_id && (p_pbc->timeout_time < 0 || p_pbc->loop_count <= 0))
+	  vcd_warn ("PSD: selection '%s': timeout target '%s' is never used due to loop count or timeout wait time given", p_pbc->id, p_pbc->timeout_id);
 
-	if (_pbc->item_id)
+	if (p_pbc->item_id)
 	  {
-	    const uint16_t _pin = _vcd_pbc_pin_lookup (obj, _pbc->item_id);
+	    const uint16_t _pin = _vcd_pbc_pin_lookup (obj, p_pbc->item_id);
 	    
 	    if (!_pin)
-	      vcd_error ("PSD: referenced play item '%s' not found", _pbc->item_id);
+	      vcd_error ("PSD: referenced play item '%s' not found", p_pbc->item_id);
 
 	    _md->itemid = uint16_to_be (_pin);
 	  }
@@ -652,30 +653,30 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
 	  _md->itemid = 0; /* play nothing */
 
 	/* sanity checks */
-	switch (_pbc->selection_type)
+	switch (p_pbc->selection_type)
 	  {
 	  case _SEL_NORMAL:
 	    break;
 	    
 	  case _SEL_MULTI_DEF:
 	  case _SEL_MULTI_DEF_NO_NUM:
-	    if (_pbc->jump_delayed)
-	      vcd_warn ("selection '%s': jump timing shall be immediate", _pbc->id);
+	    if (p_pbc->jump_delayed)
+	      vcd_warn ("selection '%s': jump timing shall be immediate", p_pbc->id);
 
-	    if (_pbc->bsn != 1)
+	    if (p_pbc->bsn != 1)
 	      vcd_error ("selection '%s': BSN != 1 for multi default selection",
-			 _pbc->id);
+			 p_pbc->id);
 
 	    /* checking NOS == NOE */
-	    if (!_pbc->item_id)
+	    if (!p_pbc->item_id)
 	      vcd_error ("selection '%s': play nothing play item not allowed for multidefault list",
-			 _pbc->id);
+			 p_pbc->id);
 
 	    {
 	      mpeg_sequence_t *_seq;
 
-	      if ((_seq = _vcd_obj_get_sequence_by_id ((VcdObj *) obj, _pbc->item_id))
-		  || (_seq = _vcd_obj_get_sequence_by_entry_id ((VcdObj *) obj, _pbc->item_id)))
+	      if ((_seq = _vcd_obj_get_sequence_by_id ((VcdObj_t *) obj, p_pbc->item_id))
+		  || (_seq = _vcd_obj_get_sequence_by_entry_id ((VcdObj_t *) obj, p_pbc->item_id)))
 		{
 		  const unsigned _entries = 
 		    _cdio_list_length (_seq->entry_list) + 1;
@@ -683,13 +684,13 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
 		  if (_nos != _entries)
 		    vcd_error ("selection '%s': number of entrypoints"
 			       " (%d for sequence '%s') != number of selections (%d)",
-			       _pbc->id, _entries, _pbc->item_id, _nos);
+			       p_pbc->id, _entries, p_pbc->item_id, _nos);
 		}
 	      else
 		vcd_error ("selection '%s': play item '%s'"
 			   " is requried to be sequence or entry point"
 			   " item for multi default selecton",
-			   _pbc->id, _pbc->item_id);
+			   p_pbc->id, p_pbc->item_id);
 	    }	    
 
 	    break;
@@ -701,11 +702,11 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
 
 	/* fill selection array */
 	{
-	  CdioListNode *node = NULL;
+	  CdioListNode_t *node = NULL;
 	  int idx = 0;
 
 	  idx = 0;
-	  _CDIO_LIST_FOREACH (node, _pbc->select_id_list)
+	  _CDIO_LIST_FOREACH (node, p_pbc->select_id_list)
 	    {
 	      const char *_id = _cdio_list_node_data (node);
 	    
@@ -718,27 +719,27 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
 
 	if (extended || _vcd_obj_has_cap_p (obj, _CAP_4C_SVCD))
 	  {
-	    PsdSelectionListDescriptorExtended *_md2;
-	    CdioListNode *node;
+	    PsdSelectionListDescriptorExtended_t *_md2;
+	    CdioListNode_t *node;
 	    int n;
 	    
 	    /* append extended selection areas */
 
 	    _md2 = (void *) &_md->ofs[_nos];
 
-	    _set_area_helper (&_md2->next_area, _pbc->next_area, _pbc->id);
-	    _set_area_helper (&_md2->prev_area, _pbc->prev_area, _pbc->id);
-	    _set_area_helper (&_md2->return_area, _pbc->return_area, _pbc->id);
+	    _set_area_helper (&_md2->next_area, p_pbc->next_area, p_pbc->id);
+	    _set_area_helper (&_md2->prev_area, p_pbc->prev_area, p_pbc->id);
+	    _set_area_helper (&_md2->return_area, p_pbc->return_area, p_pbc->id);
 
-	    _set_area_helper (&_md2->default_area, _pbc->default_area, _pbc->id);
+	    _set_area_helper (&_md2->default_area, p_pbc->default_area, p_pbc->id);
 
 	    n = 0;
-	    if (_pbc->select_area_list)
-	      _CDIO_LIST_FOREACH (node, _pbc->select_area_list)
+	    if (p_pbc->select_area_list)
+	      _CDIO_LIST_FOREACH (node, p_pbc->select_area_list)
 	      {
 		const pbc_area_t *_area = _cdio_list_node_data (node);
 
-		_set_area_helper (&_md2->area[n], _area, _pbc->id);
+		_set_area_helper (&_md2->area[n], _area, p_pbc->id);
 
 		n++;
 	      }
@@ -750,46 +751,46 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
       
     case PBC_END:
       {
-	PsdEndListDescriptor *_md = buf;
+	PsdEndListDescriptor_t *_md = buf;
 
 	_md->type = PSD_TYPE_END_LIST;
 
 	if (_vcd_obj_has_cap_p (obj, _CAP_4C_SVCD))
 	  {
-	    _md->next_disc = _pbc->next_disc;
+	    _md->next_disc = p_pbc->next_disc;
 
-	    if (_pbc->image_id)
+	    if (p_pbc->image_id)
 	      {
-		uint16_t _pin = _vcd_pbc_pin_lookup (obj, _pbc->image_id);
+		uint16_t _pin = _vcd_pbc_pin_lookup (obj, p_pbc->image_id);
 		mpeg_segment_t *_segment;
 
-		if (!_pbc->next_disc)
+		if (!p_pbc->next_disc)
 		  vcd_warn ("PSD: endlist '%s': change disc picture given,"
-			    " but next volume is 0", _pbc->id);
+			    " but next volume is 0", p_pbc->id);
 
 		if (!_pin)
 		  vcd_error ("PSD: referenced play item '%s' not found", 
-			     _pbc->item_id);
+			     p_pbc->item_id);
 
 		_md->change_pic = uint16_to_be (_pin);
 
 		/* sanity checks */
 
-		_segment = _vcd_obj_get_segment_by_id ((VcdObj *) obj,
-						       _pbc->image_id);
+		_segment = _vcd_obj_get_segment_by_id ((VcdObj_t *) obj,
+						       p_pbc->image_id);
 
 		if (!_segment)
 		  vcd_warn ("PSD: endlist '%s': referenced play item '%s'"
 			    " is not a segment play item", 
-			    _pbc->id, _pbc->image_id);
+			    p_pbc->id, p_pbc->image_id);
 		else if (_segment->info->shdr[0].seen
 			 || !(_segment->info->shdr[1].seen || _segment->info->shdr[2].seen))
 		  vcd_warn ("PSD: endlist '%s': referenced play item '%s'"
 			    " should be a still picture", 
-			    _pbc->id, _pbc->image_id);
+			    p_pbc->id, p_pbc->image_id);
 	      }
 	  }
-	else if (_pbc->next_disc || _pbc->image_id)
+	else if (p_pbc->next_disc || p_pbc->image_id)
 	  vcd_warn ("extended end list attributes ignored for non-SVCD");
       }
       break;
@@ -803,20 +804,20 @@ _vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
 pbc_t *
 vcd_pbc_new (enum pbc_type_t type)
 {
-  pbc_t *_pbc;
+  pbc_t *p_pbc;
 
-  _pbc = _vcd_malloc (sizeof (pbc_t));
-  _pbc->type = type;
+  p_pbc = calloc(1, sizeof (pbc_t));
+  p_pbc->type = type;
 
   switch (type)
     {
     case PBC_PLAYLIST:
-      _pbc->item_id_list = _cdio_list_new ();
+      p_pbc->item_id_list = _cdio_list_new ();
       break;
 
     case PBC_SELECTION:
-      _pbc->select_id_list = _cdio_list_new ();
-      _pbc->select_area_list = _cdio_list_new ();
+      p_pbc->select_id_list = _cdio_list_new ();
+      p_pbc->select_area_list = _cdio_list_new ();
       break;
       
     case PBC_END:
@@ -827,16 +828,50 @@ vcd_pbc_new (enum pbc_type_t type)
       break;
     }
 
-  return _pbc;
+  return p_pbc;
+}
+
+void
+vcd_pbc_destroy (pbc_t *p_pbc)
+{
+  free(p_pbc->default_id);
+  free(p_pbc->id);
+  free(p_pbc->prev_area);
+  free(p_pbc->prev_id);
+  free(p_pbc->next_area);
+  free(p_pbc->next_id);
+  free(p_pbc->default_area);
+  free(p_pbc->return_area);
+  free(p_pbc->retn_id);
+  free(p_pbc->timeout_id);
+  free(p_pbc->item_id);
+  switch (p_pbc->type)
+    {
+    case PBC_PLAYLIST:
+      _cdio_list_free (p_pbc->item_id_list, false);
+      break;
+
+    case PBC_SELECTION:
+      _cdio_list_free (p_pbc->select_id_list, true);
+      _cdio_list_free (p_pbc->select_area_list, true);
+      break;
+      
+    case PBC_END:
+      break;
+
+    default:
+      vcd_assert_not_reached ();
+      break;
+    }
 }
 
 /* 
  */
 
 bool
-_vcd_pbc_finalize (VcdObj *obj)
+_vcd_pbc_finalize (VcdObj_t *obj)
 {
-  CdioListNode *node;
+  CdioListNode_t *node;
   unsigned offset = 0, offset_ext = 0;
   unsigned lid;
 
