@@ -1,5 +1,5 @@
 /*
-    $Id: pbc.h,v 1.3 2004/10/10 20:20:19 rocky Exp $
+    $Id: pbc.h,v 1.6 2005/05/08 03:48:55 rocky Exp $
 
     Copyright (C) 2000 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -41,7 +41,7 @@ typedef struct psd_area_t pbc_area_t; /* fixme */
 static inline pbc_area_t *
 vcd_pbc_area_new (uint8_t x1, uint8_t y1, uint8_t x2, uint8_t y2)
 {
-  pbc_area_t *_new_area = _vcd_malloc (sizeof (pbc_area_t));
+  pbc_area_t *_new_area = calloc(1, sizeof (pbc_area_t));
 
   _new_area->x1 = x1;
   _new_area->y1 = y1;
@@ -72,7 +72,7 @@ struct _pbc_t {
   double playing_time;
   int wait_time;
   int auto_pause_time;
-  CdioList *item_id_list; /* char */
+  CdioList_t *item_id_list; /* char */
 
   /* used for selection lists */
   enum selection_type_t {
@@ -85,7 +85,7 @@ struct _pbc_t {
   pbc_area_t *next_area;
   pbc_area_t *return_area;
   pbc_area_t *default_area; /* depends on selection_type */
-  CdioList *select_area_list; /* pbc_area_t */
+  CdioList_t *select_area_list; /* pbc_area_t */
 
   unsigned bsn;
   char *default_id;
@@ -94,7 +94,7 @@ struct _pbc_t {
   unsigned loop_count;
   bool jump_delayed;
   char *item_id;
-  CdioList *select_id_list; /* char */
+  CdioList_t *select_id_list; /* char */
 
   /* used for end lists */
   char *image_id;
@@ -121,37 +121,37 @@ pbc_t *
 vcd_pbc_new (enum pbc_type_t type);
 
 pbc_t *
-_vcd_pbc_init (pbc_t *_pbc);
+_vcd_pbc_init (pbc_t *p_pbc);
 
 void
-vcd_pbc_destroy (pbc_t *obj);
+vcd_pbc_destroy (pbc_t *p_pbc);
 
 unsigned
-_vcd_pbc_lid_lookup (const VcdObj *obj, const char item_id[]);
+_vcd_pbc_lid_lookup (const VcdObj_t *obj, const char item_id[]);
 
 enum item_type_t
-_vcd_pbc_lookup (const VcdObj *obj, const char item_id[]);
+_vcd_pbc_lookup (const VcdObj_t *obj, const char item_id[]);
 
 uint16_t
-_vcd_pbc_pin_lookup (const VcdObj *obj, const char item_id[]);
+_vcd_pbc_pin_lookup (const VcdObj_t *obj, const char item_id[]);
 
 unsigned 
 _vcd_pbc_list_calc_size (const pbc_t *_pbc, bool extended);
 
 bool
-_vcd_pbc_finalize (VcdObj *obj);
+_vcd_pbc_finalize (VcdObj_t *obj);
 
 bool
-_vcd_pbc_available (const VcdObj *obj);
+_vcd_pbc_available (const VcdObj_t *obj);
 
 uint16_t
-_vcd_pbc_max_lid (const VcdObj *obj);
+_vcd_pbc_max_lid (const VcdObj_t *obj);
 
 void
-_vcd_pbc_node_write (const VcdObj *obj, const pbc_t *_pbc, void *buf,
+_vcd_pbc_node_write (const VcdObj_t *obj, const pbc_t *_pbc, void *buf,
 		     bool extended);
 
 void
-_vcd_pbc_check_unreferenced (const VcdObj *obj);
+_vcd_pbc_check_unreferenced (const VcdObj_t *obj);
 
 #endif /* __VCD_PBC_H__ */
